Re: CVS commit: src

2019-09-02 Thread Taylor R Campbell
> Date: Mon, 2 Sep 2019 14:23:14 +
> From: Taylor R Campbell 
> 
> > Date: Mon, 2 Sep 2019 16:53:34 +0900
> > From: Masanobu SAITOH 
> > 
> > d) Any other options.
> 
> 1. Revert the commit for now, ASAP, to unblock people.

So, it turns out this is more complicated than I thought.

msaitoh pointed out that since the files have now been installed, it
seems appropriate to mark them as obsolete when reverting the commit.

However, if we add them to obsolete, then I expect that on a case-
insensitive file system, when build.sh distribution runs postinstall
on $DESTDIR, and it tries to delete the new (bad) files, it will have
the effect of deleting the old (good) files too because their names
differ only in case.

So we need to clean this up _without_ marking anything as obsolete
(and then add a note to UPDATING and post an announcement to
current-users explaining what happened and advising everyone to
manually delete the new (bad) files).


How do we clean it up?

1. We could simply revert the commits, but that will nevertheless
   break checkout by date on case-insensitive file systems, which
   implies breaking bisection over the past week on case-insensitive
   file systems.

2. We could move the ,v files to a subdirectory as christos suggested,
   but the Makefile changes would then refer to files that don't
   exist, which implies breaking bisection over the past week for
   everyone.

I am not seeing a good way out of this.  I'm inclined to weigh
`bisection for everyone' as more important than `bisection on
case-insensitive file systems', and to prefer (1) over (2), but maybe
there are other downsides to leaving the ,v files around and other
reasons why we should do (2) instead of (1).

Thoughts?


CVS commit: src/external/bsd/compiler_rt/lib/clang/lib/netbsd

2019-09-02 Thread Kamil Rytarowski
Module Name:src
Committed By:   kamil
Date:   Tue Sep  3 03:04:31 UTC 2019

Modified Files:
src/external/bsd/compiler_rt/lib/clang/lib/netbsd: common.mk

Log Message:
Set NOLIBCSANITIZER for LLVM sanitizer runtimes

Do not sanitize sanitizer runtimes.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 \
src/external/bsd/compiler_rt/lib/clang/lib/netbsd/common.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/external/bsd/compiler_rt/lib/clang/lib/netbsd

2019-09-02 Thread Kamil Rytarowski
Module Name:src
Committed By:   kamil
Date:   Tue Sep  3 03:04:31 UTC 2019

Modified Files:
src/external/bsd/compiler_rt/lib/clang/lib/netbsd: common.mk

Log Message:
Set NOLIBCSANITIZER for LLVM sanitizer runtimes

Do not sanitize sanitizer runtimes.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 \
src/external/bsd/compiler_rt/lib/clang/lib/netbsd/common.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/compiler_rt/lib/clang/lib/netbsd/common.mk
diff -u src/external/bsd/compiler_rt/lib/clang/lib/netbsd/common.mk:1.2 src/external/bsd/compiler_rt/lib/clang/lib/netbsd/common.mk:1.3
--- src/external/bsd/compiler_rt/lib/clang/lib/netbsd/common.mk:1.2	Fri Aug 16 23:07:20 2019
+++ src/external/bsd/compiler_rt/lib/clang/lib/netbsd/common.mk	Tue Sep  3 03:04:31 2019
@@ -1,2 +1,3 @@
 CLANG_VER=	7.0.0
 NODEBUG=	# defined
+NOLIBCSANITIZER=# defined



Re: CVS commit: src

2019-09-02 Thread Robert Elz
Date:Tue, 3 Sep 2019 04:07:16 +
From:Taylor R Campbell 
Message-ID:  <20190903040716.a6abe60...@jupiter.mumble.net>

  | How do we clean it up?

  | I am not seeing a good way out of this.

I do, but you are all refusing to permit it ... simply abandon support
for case insensitive filesystems.

In practice (and I admit to not really having studied any of them, as
they're all a stupid idea) I doubt that any of them really are truly
case insensitive ... rather than are insenstive to the case of ascii
chars, and that's usually it.

Are there any of these filesystems that treat capital delta the same
as lower case delta?   Or even capital U with an umlaut the same as
lower case u with an umlaut?   (or E-acute and e-acute)   etc?

And if they do, how do they manage to do that?   The only way I can
imagine is to permit only 10646 (however encoded) characters in file
names, but if the file system is like that, how do we support it when
we have files on FFS (which has no such restriction) with characters
with the top bit set?   Is such a character 8859-1, 8859-7, 8859-11?

Those 3 have different methods of mapping their upper case chars to
their lower case equivs as I understand it (for 8859-11 it is easy,
there is no case, so none of the chars in the 0x80-0xff range are
equiv to each other regardless of whether the filesys is case insensitive
or not, but that would not, should not, be true for the other two
mentioned.)

Since none of the sys calls that end up invoking namei() pass locale
info to the kernel, and even if they did, I doubt we'd want to build
case mapping locale specific tables into the kernel (anyone's kernel)
and since I see no justification at all for doing special case handing
of English but not for all other languages, I'd suggest that any unix
filesystem that doesn't treat all filenames as simply bit strings, with
special handling only for the bytes 0x2F and 0x00 is simply broken, and
we should not attempt to support that at all.

Dealing with this kind of thing belongs in the applications, where locale
info is available (or can be), and where what is appropriate for treating
two different strings as if they represent the same thing can be dealt
with in a rational way - at least rational for that application.

So, to me, the solution is simple.   Leave it all as it is now, and
simply tell people using "case insensitive" file systems to either stop
doing that, or they simply will not be able to build everything.

kre



CVS commit: [netbsd-9] src/doc

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 07:07:21 UTC 2019

Modified Files:
src/doc [netbsd-9]: CHANGES-9.0

Log Message:
Ammed ticket #144 for miidevs regen


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.35 -r1.1.2.36 src/doc/CHANGES-9.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-9] src/sys/dev/mii

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 07:06:11 UTC 2019

Modified Files:
src/sys/dev/mii [netbsd-9]: miidevs.h miidevs_data.h

Log Message:
regen (for ticket #144, also requested in ticket #171)


To generate a diff of this commit:
cvs rdiff -u -r1.151 -r1.151.2.1 src/sys/dev/mii/miidevs.h
cvs rdiff -u -r1.139 -r1.139.2.1 src/sys/dev/mii/miidevs_data.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-9] src/doc

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 07:07:21 UTC 2019

Modified Files:
src/doc [netbsd-9]: CHANGES-9.0

Log Message:
Ammed ticket #144 for miidevs regen


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.35 -r1.1.2.36 src/doc/CHANGES-9.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-9.0
diff -u src/doc/CHANGES-9.0:1.1.2.35 src/doc/CHANGES-9.0:1.1.2.36
--- src/doc/CHANGES-9.0:1.1.2.35	Sun Sep  1 19:35:17 2019
+++ src/doc/CHANGES-9.0	Mon Sep  2 07:07:21 2019
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-9.0,v 1.1.2.35 2019/09/01 19:35:17 martin Exp $
+# $NetBSD: CHANGES-9.0,v 1.1.2.36 2019/09/02 07:07:21 martin Exp $
 
 A complete list of changes from the initial NetBSD 9.0 branch on 2019-07-30
 until the 9.0 release:
@@ -2568,6 +2568,8 @@ sys/arch/x86/pci/if_vmx.c			1.49
 
 sys/dev/mii/etphy.c1.5,1.6
 sys/dev/mii/miidevs1.154
+sys/dev/mii/miidevs.h(regen)
+sys/dev/mii/miidevs_data.h			(regen)
 
 	- Rename ET1011 to ET1011C
 	- Support ET1011 to etphy(4)



Re: CVS commit: src

2019-09-02 Thread Masanobu SAITOH
Background:

 In August 2014, lower-cased filename's files are added in the following
commit:


https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/commit/radeon?id=f333bd435c0b6745cbc4fae3326725d77bf57c82

This commit says those files use the new header format. The radeon's drmkms
driver basically try to use lower case's file first and then try the upper
case's one. [*1]

After the above commit, usually lower-case's files have been added and updated.
Two exceptions:

TAHITI_vce.bin (only uppercase exists)
BONAIRE_uvd.bin (both upper and lowe exist and both updated)

Some old (upper-case'd) firmware might be maintained anymore.

Now:
Number of upper-cased filename's files: 158
Number of lower-cased filename's files: 66
Both lower-cased and upper-cased: 65

kaveri_mec2.bin has only lowercase one.
(see also:
http://mail-index.netbsd.org/tech-x11/2019/04/07/msg001953.html)

[*1] For _mc*.bin:
1st try: lower-case _mc.bin
2nd try: upper-case _mc2.bin
3rd try: upper-case _mc.bin

So, options are:

a) Remove duplicated upper-cased files.

   pros: Simple. It's not required to modify radeon driver itself.
 It also works with new kernel with old filesysysm.
   cons: If the driver failed to load the lower cased firmware,
 driver can't read the upper-cased firmware.

b) Rename upper-case'd file to another name e.g.: foo_bar_old.bin

   pros: It can be keep the driver's behavior the same as linux's.
   cons: We have to modify many files and lines.
 If we support new kernel + old filesystem, we should modify
 the driver to load FOO_BAR.bin first and then FOO_BAR_old.bin.

c) keep the current status as it is.

   pros: Any additional work is not required.
   cons: have trouble on case-insensitive file system.

d) Any other options.



-- 
---
SAITOH Masanobu (msai...@execsw.org
 msai...@netbsd.org)


Re: CVS commit: src

2019-09-02 Thread Christos Zoulas
In article <20190902082137.ga21...@mail.duskware.de>,
Martin Husemann   wrote:
>On Mon, Sep 02, 2019 at 08:18:06AM -, Christos Zoulas wrote:
>> >> b) Rename upper-case'd file to another name e.g.: foo_bar_old.bin
>> >> 
>> >>pros: It can be keep the driver's behavior the same as linux's.
>> >>cons: We have to modify many files and lines.
>> >>  If we support new kernel + old filesystem, we
>should modify
>> >>  the driver to load FOO_BAR.bin first and then
>> >FOO_BAR_old.bin.
>> 
>> This is the most intrusive option. Even if you choose to do "d" as I describe
>> below, it is probably preferrable to change the filename from:
>> 
>>  radeon/FOO_bar.bin and radeon/foo_bar.bin to
>>  radeon/FOO_bar.bin and radeon/new/foo_bar.bin 
>> 
>> There are only 2 files that need the change and due to excessive 
>> cut-n-pasting
>> there are a bunch of snprintf's that need modifying (the ones that contain
>> new_chip_name in src/sys/external/bsd/drm2/dist/drm/radeon: radeon_si.c
>> and radeon_cik.c)
>
>Can we bring this up upstream and ask them to rename?

Sure, but that will take time; so we need to do something now, and also
ask upstream to make the change. But I don't think that upstream will
change it (because they could have in the first place if they did not
want to keep the compat names).

christos



CVS commit: src

2019-09-02 Thread Roy Marples
Module Name:src
Committed By:   roy
Date:   Mon Sep  2 09:08:29 UTC 2019

Modified Files:
src/distrib/sets/lists/comp: mi
src/lib/libcurses: Makefile curses.3 curses.h
Added Files:
src/lib/libcurses: curses_version.3 version.c

Log Message:
curses(3): add curses_version()

Returns NetBSD-Curses %s
Where %s is the NetBSD version taken from sys/param.h

Discussed on tech-net@, only for ncurses compat.


To generate a diff of this commit:
cvs rdiff -u -r1.2284 -r1.2285 src/distrib/sets/lists/comp/mi
cvs rdiff -u -r1.90 -r1.91 src/lib/libcurses/Makefile
cvs rdiff -u -r1.73 -r1.74 src/lib/libcurses/curses.3
cvs rdiff -u -r1.123 -r1.124 src/lib/libcurses/curses.h
cvs rdiff -u -r0 -r1.1 src/lib/libcurses/curses_version.3 \
src/lib/libcurses/version.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-9] src/sys/dev/usb

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 07:02:34 UTC 2019

Modified Files:
src/sys/dev/usb [netbsd-9]: if_aue.c

Log Message:
Ticket #135: something went wrong in the pullup process for this file
(likely overlooked conflict with previously applied rev. 156).
So now actually sync this up to rev 1.161, as the last pullup claimed


To generate a diff of this commit:
cvs rdiff -u -r1.154.2.1 -r1.154.2.2 src/sys/dev/usb/if_aue.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/usb/if_aue.c
diff -u src/sys/dev/usb/if_aue.c:1.154.2.1 src/sys/dev/usb/if_aue.c:1.154.2.2
--- src/sys/dev/usb/if_aue.c:1.154.2.1	Fri Aug  9 16:15:06 2019
+++ src/sys/dev/usb/if_aue.c	Mon Sep  2 07:02:34 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_aue.c,v 1.154.2.1 2019/08/09 16:15:06 martin Exp $	*/
+/*	$NetBSD: if_aue.c,v 1.154.2.2 2019/09/02 07:02:34 martin Exp $	*/
 
 /*
  * Copyright (c) 1997, 1998, 1999, 2000
@@ -70,14 +70,13 @@
 /*
  * TODO:
  * better error messages from rxstat
- * split out if_auevar.h
  * more error checks
  * investigate short rx problem
  * proper cleanup on errors
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: if_aue.c,v 1.154.2.1 2019/08/09 16:15:06 martin Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_aue.c,v 1.154.2.2 2019/09/02 07:02:34 martin Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_usb.h"
@@ -85,51 +84,75 @@ __KERNEL_RCSID(0, "$NetBSD: if_aue.c,v 1
 #endif
 
 #include 
-#include 
-#include 
-#include 
-#include 
-#include 
-#include 
-#include 
-#include 
-
-#include 
-#include 
-#include 
-#include 
 
-#include 
+#include 
+#include 
+#include 
 
-#include 
 #ifdef INET
 #include 
 #include 
 #endif
 
+#ifdef USB_DEBUG
+#ifndef AUE_DEBUG
+#define auedebug 0
+#else
+static int auedebug = 10;
 
+SYSCTL_SETUP(sysctl_hw_aue_setup, "sysctl hw.aue setup")
+{
+	int err;
+	const struct sysctlnode *rnode;
+	const struct sysctlnode *cnode;
+
+	err = sysctl_createv(clog, 0, NULL, ,
+	CTLFLAG_PERMANENT, CTLTYPE_NODE, "aue",
+	SYSCTL_DESCR("aue global controls"),
+	NULL, 0, NULL, 0, CTL_HW, CTL_CREATE, CTL_EOL);
+
+	if (err)
+		goto fail;
+
+	/* control debugging printfs */
+	err = sysctl_createv(clog, 0, , ,
+	CTLFLAG_PERMANENT | CTLFLAG_READWRITE, CTLTYPE_INT,
+	"debug", SYSCTL_DESCR("Enable debugging output"),
+	NULL, 0, , sizeof(auedebug), CTL_CREATE, CTL_EOL);
+	if (err)
+		goto fail;
 
-#include 
-#include 
-
-#include 
-#include 
-#include 
-#include 
+	return;
+fail:
+	aprint_error("%s: sysctl_createv failed (err = %d)\n", __func__, err);
+}
 
-#include 
-#include 
+#endif /* AXE_DEBUG */
+#endif /* USB_DEBUG */
 
-#include 
+#define DPRINTF(FMT,A,B,C,D)	USBHIST_LOGN(auedebug,1,FMT,A,B,C,D)
+#define DPRINTFN(N,FMT,A,B,C,D)	USBHIST_LOGN(auedebug,N,FMT,A,B,C,D)
+#define AUEHIST_FUNC()		USBHIST_FUNC()
+#define AUEHIST_CALLED(name)	USBHIST_CALLED(auedebug)
+#define AUEHIST_CALLARGS(FMT,A,B,C,D) \
+USBHIST_CALLARGS(auedebug,FMT,A,B,C,D)
+#define AUEHIST_CALLARGSN(N,FMT,A,B,C,D) \
+USBHIST_CALLARGSN(auedebug,N,FMT,A,B,C,D)
+
+#define AUE_TX_LIST_CNT		1
+#define AUE_RX_LIST_CNT		1
+
+struct aue_softc {
+	struct usbnet		aue_un;
+	struct usbnet_intr	aue_intr;
+	struct aue_intrpkt	aue_ibuf;
+};
 
-#ifdef AUE_DEBUG
-#define DPRINTF(x)	if (auedebug) printf x
-#define DPRINTFN(n, x)	if (auedebug >= (n)) printf x
-int	auedebug = 0;
-#else
-#define DPRINTF(x)
-#define DPRINTFN(n, x)
-#endif
+#define AUE_TIMEOUT		1000
+#define AUE_BUFSZ		1536
+#define AUE_MIN_FRAMELEN	60
+#define AUE_TX_TIMEOUT		1 /* ms */
+#define AUE_INTR_INTERVAL	100 /* ms */
 
 /*
  * Various supported device vendors/products.
@@ -142,7 +165,7 @@ struct aue_type {
 #define PII	0x0004		/* Pegasus II chip */
 };
 
-Static const struct aue_type aue_devs[] = {
+static const struct aue_type aue_devs[] = {
  {{ USB_VENDOR_3COM,		USB_PRODUCT_3COM_3C460B},	  PII },
  {{ USB_VENDOR_ABOCOM,		USB_PRODUCT_ABOCOM_XX1},	  PNA | PII },
  {{ USB_VENDOR_ABOCOM,		USB_PRODUCT_ABOCOM_XX2},	  PII },
@@ -210,49 +233,42 @@ Static const struct aue_type aue_devs[] 
 
 int aue_match(device_t, cfdata_t, void *);
 void aue_attach(device_t, device_t, void *);
-int aue_detach(device_t, int);
-int aue_activate(device_t, enum devact);
 
 CFATTACH_DECL_NEW(aue, sizeof(struct aue_softc), aue_match, aue_attach,
-aue_detach, aue_activate);
+usbnet_detach, usbnet_activate);
+
+static void aue_reset_pegasus_II(struct aue_softc *);
 
-Static void aue_multithread(void *);
+static void aue_stop_cb(struct ifnet *, int);
+static int aue_ioctl_cb(struct ifnet *, u_long, void *);
+static int aue_mii_read_reg(struct usbnet *, int, int, uint16_t *);
+static int aue_mii_write_reg(struct usbnet *, int, int, uint16_t);
+static void aue_mii_statchg(struct ifnet *);
+static unsigned aue_tx_prepare(struct usbnet *, struct mbuf *,
+			   struct usbnet_chain *);
+static void aue_rx_loop(struct usbnet *, struct usbnet_chain *, 

CVS commit: [netbsd-9] src/sys/dev/usb

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 07:02:34 UTC 2019

Modified Files:
src/sys/dev/usb [netbsd-9]: if_aue.c

Log Message:
Ticket #135: something went wrong in the pullup process for this file
(likely overlooked conflict with previously applied rev. 156).
So now actually sync this up to rev 1.161, as the last pullup claimed


To generate a diff of this commit:
cvs rdiff -u -r1.154.2.1 -r1.154.2.2 src/sys/dev/usb/if_aue.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/dev/ic

2019-09-02 Thread Michael van Elst
Module Name:src
Committed By:   mlelstv
Date:   Mon Sep  2 07:25:48 UTC 2019

Modified Files:
src/sys/dev/ic: bwfm.c

Log Message:
tagging work queue as MPSAFE was premature. Revert.


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.16 src/sys/dev/ic/bwfm.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/ic/bwfm.c
diff -u src/sys/dev/ic/bwfm.c:1.15 src/sys/dev/ic/bwfm.c:1.16
--- src/sys/dev/ic/bwfm.c:1.15	Sun Sep  1 05:40:39 2019
+++ src/sys/dev/ic/bwfm.c	Mon Sep  2 07:25:48 2019
@@ -1,4 +1,4 @@
-/* $NetBSD: bwfm.c,v 1.15 2019/09/01 05:40:39 mlelstv Exp $ */
+/* $NetBSD: bwfm.c,v 1.16 2019/09/02 07:25:48 mlelstv Exp $ */
 /* $OpenBSD: bwfm.c,v 1.5 2017/10/16 22:27:16 patrick Exp $ */
 /*
  * Copyright (c) 2010-2016 Broadcom Corporation
@@ -143,7 +143,7 @@ bwfm_attach(struct bwfm_softc *sc)
 	int i, j, error;
 
 	error = workqueue_create(>sc_taskq, DEVNAME(sc),
-	bwfm_task, sc, PRI_NONE, IPL_NET, WQ_MPSAFE);
+	bwfm_task, sc, PRI_NONE, IPL_NET, 0);
 	if (error != 0) {
 		printf("%s: could not create workqueue\n", DEVNAME(sc));
 		return;



CVS commit: src/sys/dev/ic

2019-09-02 Thread Michael van Elst
Module Name:src
Committed By:   mlelstv
Date:   Mon Sep  2 07:25:48 UTC 2019

Modified Files:
src/sys/dev/ic: bwfm.c

Log Message:
tagging work queue as MPSAFE was premature. Revert.


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.16 src/sys/dev/ic/bwfm.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/i386/stand

2019-09-02 Thread Emmanuel Dreyfus
Module Name:src
Committed By:   manu
Date:   Mon Sep  2 06:10:24 UTC 2019

Modified Files:
src/sys/arch/i386/stand/boot: boot2.c
src/sys/arch/i386/stand/efiboot: boot.c devopen.c

Log Message:
Make sure devices names are copied including last byte

Fix from M. Levinson.


To generate a diff of this commit:
cvs rdiff -u -r1.71 -r1.72 src/sys/arch/i386/stand/boot/boot2.c
cvs rdiff -u -r1.14 -r1.15 src/sys/arch/i386/stand/efiboot/boot.c
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/i386/stand/efiboot/devopen.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/i386/stand/boot/boot2.c
diff -u src/sys/arch/i386/stand/boot/boot2.c:1.71 src/sys/arch/i386/stand/boot/boot2.c:1.72
--- src/sys/arch/i386/stand/boot/boot2.c:1.71	Sun Aug 18 02:18:24 2019
+++ src/sys/arch/i386/stand/boot/boot2.c	Mon Sep  2 06:10:24 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: boot2.c,v 1.71 2019/08/18 02:18:24 manu Exp $	*/
+/*	$NetBSD: boot2.c,v 1.72 2019/09/02 06:10:24 manu Exp $	*/
 
 /*-
  * Copyright (c) 2008, 2009 The NetBSD Foundation, Inc.
@@ -172,7 +172,8 @@ parsebootfile(const char *fname, char **
 	if (default_part_name == NULL) {
 		*devname = default_devname;
 	} else {
-		snprintf(savedevname, MAXDEVNAME, "NAME=%s", default_part_name);
+		snprintf(savedevname, sizeof(savedevname),
+		"NAME=%s", default_part_name);
 		*devname = savedevname;
 	}
 	*unit = default_unit;

Index: src/sys/arch/i386/stand/efiboot/boot.c
diff -u src/sys/arch/i386/stand/efiboot/boot.c:1.14 src/sys/arch/i386/stand/efiboot/boot.c:1.15
--- src/sys/arch/i386/stand/efiboot/boot.c:1.14	Sun Aug 18 02:18:24 2019
+++ src/sys/arch/i386/stand/efiboot/boot.c	Mon Sep  2 06:10:24 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: boot.c,v 1.14 2019/08/18 02:18:24 manu Exp $	*/
+/*	$NetBSD: boot.c,v 1.15 2019/09/02 06:10:24 manu Exp $	*/
 
 /*-
  * Copyright (c) 2016 Kimihiro Nonaka 
@@ -130,7 +130,8 @@ parsebootfile(const char *fname, char **
 	if (default_part_name == NULL) {
 		*devname = default_devname;
 	} else {
-		snprintf(savedevname, MAXDEVNAME, "NAME=%s", default_part_name);
+		snprintf(savedevname, sizeof(savedevname),
+		"NAME=%s", default_part_name);
 		*devname = savedevname;
 	}
 	*unit = default_unit;

Index: src/sys/arch/i386/stand/efiboot/devopen.c
diff -u src/sys/arch/i386/stand/efiboot/devopen.c:1.6 src/sys/arch/i386/stand/efiboot/devopen.c:1.7
--- src/sys/arch/i386/stand/efiboot/devopen.c:1.6	Sun Aug 18 02:18:24 2019
+++ src/sys/arch/i386/stand/efiboot/devopen.c	Mon Sep  2 06:10:24 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: devopen.c,v 1.6 2019/08/18 02:18:24 manu Exp $	 */
+/*	$NetBSD: devopen.c,v 1.7 2019/09/02 06:10:24 manu Exp $	 */
 
 /*-
  * Copyright (c) 2005 The NetBSD Foundation, Inc.
@@ -100,7 +100,8 @@ bios2dev(int biosdev, daddr_t sector, ch
 
 	(void)biosdisk_findpartition(biosdev, sector, partition, part_name);
 	if (*part_name != NULL) {
-		snprintf(savedevname, MAXDEVNAME, "NAME=%s", *part_name);
+		snprintf(savedevname, sizeof(savedevname),
+		"NAME=%s", *part_name);
 			*devname = savedevname;
 	}
 }



CVS commit: src/sys/arch/i386/stand

2019-09-02 Thread Emmanuel Dreyfus
Module Name:src
Committed By:   manu
Date:   Mon Sep  2 06:10:24 UTC 2019

Modified Files:
src/sys/arch/i386/stand/boot: boot2.c
src/sys/arch/i386/stand/efiboot: boot.c devopen.c

Log Message:
Make sure devices names are copied including last byte

Fix from M. Levinson.


To generate a diff of this commit:
cvs rdiff -u -r1.71 -r1.72 src/sys/arch/i386/stand/boot/boot2.c
cvs rdiff -u -r1.14 -r1.15 src/sys/arch/i386/stand/efiboot/boot.c
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/i386/stand/efiboot/devopen.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-9] src/sys/dev/mii

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 07:06:11 UTC 2019

Modified Files:
src/sys/dev/mii [netbsd-9]: miidevs.h miidevs_data.h

Log Message:
regen (for ticket #144, also requested in ticket #171)


To generate a diff of this commit:
cvs rdiff -u -r1.151 -r1.151.2.1 src/sys/dev/mii/miidevs.h
cvs rdiff -u -r1.139 -r1.139.2.1 src/sys/dev/mii/miidevs_data.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/mii/miidevs.h
diff -u src/sys/dev/mii/miidevs.h:1.151 src/sys/dev/mii/miidevs.h:1.151.2.1
--- src/sys/dev/mii/miidevs.h:1.151	Thu Jun  6 16:05:45 2019
+++ src/sys/dev/mii/miidevs.h	Mon Sep  2 07:06:11 2019
@@ -1,10 +1,10 @@
-/*	$NetBSD: miidevs.h,v 1.151 2019/06/06 16:05:45 thorpej Exp $	*/
+/*	$NetBSD: miidevs.h,v 1.151.2.1 2019/09/02 07:06:11 martin Exp $	*/
 
 /*
  * THIS FILE AUTOMATICALLY GENERATED.  DO NOT EDIT.
  *
  * generated from:
- *	NetBSD: miidevs,v 1.153 2019/06/06 16:04:13 thorpej Exp
+ *	NetBSD: miidevs,v 1.153.2.1 2019/09/01 13:56:01 martin Exp
  */
 
 /*-
@@ -131,8 +131,10 @@
 /*
  * Agere PHYs
  */
-#define	MII_MODEL_AGERE_ET1011	0x0004
-#define	MII_STR_AGERE_ET1011	"Agere ET1011 10/100/1000baseT PHY"
+#define	MII_MODEL_AGERE_ET1011	0x0001
+#define	MII_STR_AGERE_ET1011	"ET1011 10/100/1000baseT PHY"
+#define	MII_MODEL_AGERE_ET1011C	0x0004
+#define	MII_STR_AGERE_ET1011C	"ET1011C 10/100/1000baseT PHY"
 
 /* Asix semiconductor PHYs */
 #define	MII_MODEL_xxASIX_AX88X9X	0x0031

Index: src/sys/dev/mii/miidevs_data.h
diff -u src/sys/dev/mii/miidevs_data.h:1.139 src/sys/dev/mii/miidevs_data.h:1.139.2.1
--- src/sys/dev/mii/miidevs_data.h:1.139	Thu Jun  6 16:05:45 2019
+++ src/sys/dev/mii/miidevs_data.h	Mon Sep  2 07:06:11 2019
@@ -1,10 +1,10 @@
-/*	$NetBSD: miidevs_data.h,v 1.139 2019/06/06 16:05:45 thorpej Exp $	*/
+/*	$NetBSD: miidevs_data.h,v 1.139.2.1 2019/09/02 07:06:11 martin Exp $	*/
 
 /*
  * THIS FILE AUTOMATICALLY GENERATED.  DO NOT EDIT.
  *
  * generated from:
- *	NetBSD: miidevs,v 1.153 2019/06/06 16:04:13 thorpej Exp
+ *	NetBSD: miidevs,v 1.153.2.1 2019/09/01 13:56:01 martin Exp
  */
 
 /*-
@@ -43,6 +43,7 @@ struct mii_knowndev {
 };
 struct mii_knowndev mii_knowndevs[] = {
  { MII_OUI_AGERE, MII_MODEL_AGERE_ET1011, MII_STR_AGERE_ET1011 },
+ { MII_OUI_AGERE, MII_MODEL_AGERE_ET1011C, MII_STR_AGERE_ET1011C },
  { MII_OUI_xxASIX, MII_MODEL_xxASIX_AX88X9X, MII_STR_xxASIX_AX88X9X },
  { MII_OUI_yyASIX, MII_MODEL_yyASIX_AX88772, MII_STR_yyASIX_AX88772 },
  { MII_OUI_yyASIX, MII_MODEL_yyASIX_AX88772A, MII_STR_yyASIX_AX88772A },



Re: CVS commit: src

2019-09-02 Thread Martin Husemann
On Mon, Sep 02, 2019 at 08:18:06AM -, Christos Zoulas wrote:
> >> b) Rename upper-case'd file to another name e.g.: foo_bar_old.bin
> >> 
> >>pros: It can be keep the driver's behavior the same as linux's.
> >>cons: We have to modify many files and lines.
> >>  If we support new kernel + old filesystem, we should 
> >> modify
> >>  the driver to load FOO_BAR.bin first and then
> >FOO_BAR_old.bin.
> 
> This is the most intrusive option. Even if you choose to do "d" as I describe
> below, it is probably preferrable to change the filename from:
> 
>   radeon/FOO_bar.bin and radeon/foo_bar.bin to
>   radeon/FOO_bar.bin and radeon/new/foo_bar.bin 
> 
> There are only 2 files that need the change and due to excessive cut-n-pasting
> there are a bunch of snprintf's that need modifying (the ones that contain
> new_chip_name in src/sys/external/bsd/drm2/dist/drm/radeon: radeon_si.c
> and radeon_cik.c)

Can we bring this up upstream and ask them to rename?

Martin


CVS commit: src/sys/arch/evbarm/conf

2019-09-02 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Mon Sep  2 06:08:04 UTC 2019

Modified Files:
src/sys/arch/evbarm/conf: GENERIC64

Log Message:
Add (commented out) UVMHIST options


To generate a diff of this commit:
cvs rdiff -u -r1.105 -r1.106 src/sys/arch/evbarm/conf/GENERIC64

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/arch/evbarm/conf

2019-09-02 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Mon Sep  2 06:08:04 UTC 2019

Modified Files:
src/sys/arch/evbarm/conf: GENERIC64

Log Message:
Add (commented out) UVMHIST options


To generate a diff of this commit:
cvs rdiff -u -r1.105 -r1.106 src/sys/arch/evbarm/conf/GENERIC64

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/conf/GENERIC64
diff -u src/sys/arch/evbarm/conf/GENERIC64:1.105 src/sys/arch/evbarm/conf/GENERIC64:1.106
--- src/sys/arch/evbarm/conf/GENERIC64:1.105	Tue Aug 13 17:21:01 2019
+++ src/sys/arch/evbarm/conf/GENERIC64	Mon Sep  2 06:08:04 2019
@@ -1,5 +1,5 @@
 #
-#	$NetBSD: GENERIC64,v 1.105 2019/08/13 17:21:01 tnn Exp $
+#	$NetBSD: GENERIC64,v 1.106 2019/09/02 06:08:04 skrll Exp $
 #
 #	GENERIC ARM (aarch64) kernel
 #
@@ -122,6 +122,9 @@ pseudo-device 	openfirm	# /dev/openfirm
 #options 	PMAP_DEBUG	# Enable pmap_debug_level code
 #options 	VERBOSE_INIT_ARM # verbose bootstrapping messages
 options 	INCLUDE_CONFIG_FILE
+#options 	UVMHIST
+#options 	UVMHIST_PRINT,KERNHIST_DELAY=0
+
 # EARLYCONS is required for early init messages from VERBOSE_INIT_ARM.
 #options 	EARLYCONS=bcm2837
 #options 	EARLYCONS=meson, CONSADDR=0xc81004c0



Re: CVS commit: src

2019-09-02 Thread Masanobu SAITOH
On 2019/09/02 16:53, Masanobu SAITOH wrote:
> Background:
> 
>  In August 2014, lower-cased filename's files are added in the following
> commit:
> 
> 
> https://git.kernel.org/pub/scm/linux/kernel/git/firmware/linux-firmware.git/commit/radeon?id=f333bd435c0b6745cbc4fae3326725d77bf57c82
> 
> This commit says those files use the new header format. The radeon's drmkms
> driver basically try to use lower case's file first and then try the upper
> case's one. [*1]
> 
> After the above commit, usually lower-case's files have been added and 
> updated.
> Two exceptions:
> 
> TAHITI_vce.bin (only uppercase exists)
> BONAIRE_uvd.bin (both upper and lowe exist and both updated)
> 
> Some old (upper-case'd) firmware might be maintained anymore.
> 
> Now:
> Number of upper-cased filename's files: 158
> Number of lower-cased filename's files: 66
> Both lower-cased and upper-cased: 65
> 
> kaveri_mec2.bin has only lowercase one.
> (see also:
> http://mail-index.netbsd.org/tech-x11/2019/04/07/msg001953.html)
> 
> [*1] For _mc*.bin:
> 1st try: lower-case _mc.bin
> 2nd try: upper-case _mc2.bin
> 3rd try: upper-case _mc.bin
> 
> So, options are:
> 
> a) Remove duplicated upper-cased files.
> 
>pros: Simple. It's not required to modify radeon driver itself.
>  It also works with new kernel with old filesysysm.
>cons: If the driver failed to load the lower cased firmware,
>  driver can't read the upper-cased firmware.
> 
> b) Rename upper-case'd file to another name e.g.: foo_bar_old.bin
> 
>pros: It can be keep the driver's behavior the same as linux's.
>cons: We have to modify many files and lines.
>  If we support new kernel + old filesystem, we should modify
>  the driver to load FOO_BAR.bin first and then 
> FOO_BAR_old.bin.
> 
> c) keep the current status as it is.
> 
>pros: Any additional work is not required.
>cons: have trouble on case-insensitive file system.
> 
> d) Any other options.

I prefer option A.


-- 
---
SAITOH Masanobu (msai...@execsw.org
 msai...@netbsd.org)


Re: CVS commit: src

2019-09-02 Thread Christos Zoulas
In article <5e0e69ed-deaa-4022-dbfd-f0a5d716b...@execsw.org>,
Masanobu SAITOH   wrote:
>> 
>> So, options are:
>> 
>> a) Remove duplicated upper-cased files.
>> 
>>pros: Simple. It's not required to modify radeon driver itself.
>>  It also works with new kernel with old filesysysm.
>>cons: If the driver failed to load the lower cased firmware,
>>  driver can't read the upper-cased firmware.

Are we sure that the old firmware files are not needed? I.e. are there old
chips that only work with the old firmware files and the change was not
consmetic?

>> b) Rename upper-case'd file to another name e.g.: foo_bar_old.bin
>> 
>>pros: It can be keep the driver's behavior the same as linux's.
>>cons: We have to modify many files and lines.
>>  If we support new kernel + old filesystem, we should modify
>>  the driver to load FOO_BAR.bin first and then
>FOO_BAR_old.bin.

This is the most intrusive option. Even if you choose to do "d" as I describe
below, it is probably preferrable to change the filename from:

radeon/FOO_bar.bin and radeon/foo_bar.bin to
radeon/FOO_bar.bin and radeon/new/foo_bar.bin 

There are only 2 files that need the change and due to excessive cut-n-pasting
there are a bunch of snprintf's that need modifying (the ones that contain
new_chip_name in src/sys/external/bsd/drm2/dist/drm/radeon: radeon_si.c
and radeon_cik.c)

>> 
>> c) keep the current status as it is.
>> 
>>pros: Any additional work is not required.
>>cons: have trouble on case-insensitive file system.

This is not an option. We want to be able to work on case-insensitive
filesystems.

>> d) Any other options.

On CVS
$ mkdir new
$ mv [a-z]* new
Do what you want about choosing where (or if) you want to install the old
and the new files.

christos



CVS commit: src/games/bcd

2019-09-02 Thread Thomas Klausner
Module Name:src
Committed By:   wiz
Date:   Mon Sep  2 08:26:01 UTC 2019

Modified Files:
src/games/bcd: bcd.6

Log Message:
End sentence with a dot.


To generate a diff of this commit:
cvs rdiff -u -r1.18 -r1.19 src/games/bcd/bcd.6

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/games/bcd/bcd.6
diff -u src/games/bcd/bcd.6:1.18 src/games/bcd/bcd.6:1.19
--- src/games/bcd/bcd.6:1.18	Sun Sep  1 22:50:11 2019
+++ src/games/bcd/bcd.6	Mon Sep  2 08:26:00 2019
@@ -1,4 +1,4 @@
-.\"	$NetBSD: bcd.6,v 1.18 2019/09/01 22:50:11 sevan Exp $
+.\"	$NetBSD: bcd.6,v 1.19 2019/09/02 08:26:00 wiz Exp $
 .\"
 .\" Copyright (c) 1988, 1991, 1993
 .\"	The Regents of the University of California.  All rights reserved.
@@ -89,4 +89,4 @@ A
 utility appeared in
 .At v1 .
 The current implementation originates from a rewrite included in
-.Bx 4.3 reno
+.Bx 4.3 reno .



Re: CVS commit: src/sys

2019-09-02 Thread Christos Zoulas
In article <19990.1566969...@splode.eterna.com.au>,
matthew green   wrote:
>>  src/sys/kern: vfs_bio.c
>>  src/sys/sys: buf.h
>> 
>> Log Message:
>>  Change buf_nbuf()'s return value from int to u_int to avoid undefined
>> behavior in wapbl_start() which extended int to size_t.
>> 
>> Error message was:
>> > UBSan: Undefined Behavior in ../../../../kern/vfs_wapbl.c:609:41,
>signed integer overflow: 3345138 * 1024 cannot be represented in type
>'int'
>> 
>> >/* XXX maybe use filesystem fragment size instead of 1024 */
>> > /* XXX fix actual number of buffers reserved per filesystem. */
>> > wl->wl_bufcount_max = (buf_nbuf() / 2) * 1024;
>> 
>> Need more work?
>
>i would have made buf_nbuf() return size_t.

Or u_int which is what nbuf is...

christos



CVS commit: src/games/bcd

2019-09-02 Thread Thomas Klausner
Module Name:src
Committed By:   wiz
Date:   Mon Sep  2 08:26:01 UTC 2019

Modified Files:
src/games/bcd: bcd.6

Log Message:
End sentence with a dot.


To generate a diff of this commit:
cvs rdiff -u -r1.18 -r1.19 src/games/bcd/bcd.6

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src

2019-09-02 Thread Roy Marples
Module Name:src
Committed By:   roy
Date:   Mon Sep  2 09:08:29 UTC 2019

Modified Files:
src/distrib/sets/lists/comp: mi
src/lib/libcurses: Makefile curses.3 curses.h
Added Files:
src/lib/libcurses: curses_version.3 version.c

Log Message:
curses(3): add curses_version()

Returns NetBSD-Curses %s
Where %s is the NetBSD version taken from sys/param.h

Discussed on tech-net@, only for ncurses compat.


To generate a diff of this commit:
cvs rdiff -u -r1.2284 -r1.2285 src/distrib/sets/lists/comp/mi
cvs rdiff -u -r1.90 -r1.91 src/lib/libcurses/Makefile
cvs rdiff -u -r1.73 -r1.74 src/lib/libcurses/curses.3
cvs rdiff -u -r1.123 -r1.124 src/lib/libcurses/curses.h
cvs rdiff -u -r0 -r1.1 src/lib/libcurses/curses_version.3 \
src/lib/libcurses/version.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/comp/mi
diff -u src/distrib/sets/lists/comp/mi:1.2284 src/distrib/sets/lists/comp/mi:1.2285
--- src/distrib/sets/lists/comp/mi:1.2284	Wed Aug 28 21:48:14 2019
+++ src/distrib/sets/lists/comp/mi	Mon Sep  2 09:08:29 2019
@@ -1,4 +1,4 @@
-#	$NetBSD: mi,v 1.2284 2019/08/28 21:48:14 rmind Exp $
+#	$NetBSD: mi,v 1.2285 2019/09/02 09:08:29 roy Exp $
 #
 # Note: don't delete entries from here - mark them as "obsolete" instead.
 ./etc/mtree/set.compcomp-sys-root
@@ -6336,6 +6336,7 @@
 ./usr/share/man/cat3/curses_touch.0		comp-c-catman		.cat
 ./usr/share/man/cat3/curses_tty.0		comp-c-catman		.cat
 ./usr/share/man/cat3/curses_underscore.0	comp-c-catman		.cat
+./usr/share/man/cat3/curses_version.0		comp-c-catman		.cat
 ./usr/share/man/cat3/curses_window.0		comp-c-catman		.cat
 ./usr/share/man/cat3/cuserid.0			comp-c-catman		.cat
 ./usr/share/man/cat3/d2i_ASN1_OBJECT.0	comp-c-catman	.cat,openssl=10
@@ -14342,6 +14343,7 @@
 ./usr/share/man/html3/curses_touch.html		comp-c-htmlman		html
 ./usr/share/man/html3/curses_tty.html		comp-c-htmlman		html
 ./usr/share/man/html3/curses_underscore.html	comp-c-htmlman		html
+./usr/share/man/html3/curses_version.html	comp-c-htmlman		html
 ./usr/share/man/html3/curses_window.html	comp-c-htmlman		html
 ./usr/share/man/html3/cuserid.html		comp-c-htmlman		html
 ./usr/share/man/html3/d2i_ASN1_OBJECT.html	comp-c-htmlman	html,openssl=10
@@ -22291,6 +22293,7 @@
 ./usr/share/man/man3/curses_touch.3		comp-c-man		.man
 ./usr/share/man/man3/curses_tty.3		comp-c-man		.man
 ./usr/share/man/man3/curses_underscore.3	comp-c-man		.man
+./usr/share/man/man3/curses_version.3		comp-c-man		.man
 ./usr/share/man/man3/curses_window.3		comp-c-man		.man
 ./usr/share/man/man3/cuserid.3			comp-c-man		.man
 ./usr/share/man/man3/d2i_ASN1_OBJECT.3	comp-c-man	.man,openssl=10

Index: src/lib/libcurses/Makefile
diff -u src/lib/libcurses/Makefile:1.90 src/lib/libcurses/Makefile:1.91
--- src/lib/libcurses/Makefile:1.90	Thu Nov 22 22:00:49 2018
+++ src/lib/libcurses/Makefile	Mon Sep  2 09:08:29 2019
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.90 2018/11/22 22:00:49 uwe Exp $
+#	$NetBSD: Makefile,v 1.91 2019/09/02 09:08:29 roy Exp $
 #	@(#)Makefile	8.2 (Berkeley) 1/2/94
 
 .include 
@@ -25,7 +25,7 @@ SRCS=	acs.c addbytes.c addch.c addchnstr
 	mvwin.c newwin.c nodelay.c notimeout.c overlay.c overwrite.c pause.c \
 	printw.c putchar.c refresh.c resize.c ripoffline.c scanw.c screen.c \
 	scroll.c scrollok.c setterm.c slk.c standout.c syncok.c timeout.c \
-	toucholap.c touchwin.c tstp.c tty.c unctrl.c underscore.c
+	toucholap.c touchwin.c tstp.c tty.c unctrl.c underscore.c version.c
 
 MAN=	curses.3 curses_addch.3 curses_addchstr.3 curses_addstr.3 \
 	curses_attributes.3 curses_background.3 curses_border.3 \
@@ -37,7 +37,8 @@ MAN=	curses.3 curses_addch.3 curses_addc
 	curses_insdelln.3 curses_keyname.3 curses_line.3 curses_pad.3 \
 	curses_print.3 curses_refresh.3 curses_scanw.3 curses_screen.3 \
 	curses_scroll.3 curses_slk.3 curses_standout.3 curses_termcap.3 \
-	curses_touch.3 curses_tty.3 curses_underscore.3 curses_window.3
+	curses_touch.3 curses_tty.3 curses_underscore.3 curses_version.3 \
+	curses_window.3
 INCS=	curses.h unctrl.h
 INCSDIR=/usr/include
 
@@ -209,5 +210,10 @@ SUBDIR.roff+= PSD.doc
 fileio.h: shlib_version genfileioh.awk
 	${TOOL_AWK} -f ${.CURDIR}/genfileioh.awk < ${.CURDIR}/shlib_version > ${.CURDIR}/fileio.h
 
+NETBSD_VERSION!=	${HOST_SH} ${NETBSDSRCDIR}/sys/conf/osrelease.sh
+CPPFLAGS.version.c+=	-DNETBSD_VERSION=\"${NETBSD_VERSION}\"
+.PATH:			${NETBSDSRCDIR}/sys/sys
+version.o:		param.h
+
 .include 
 .include 

Index: src/lib/libcurses/curses.3
diff -u src/lib/libcurses/curses.3:1.73 src/lib/libcurses/curses.3:1.74
--- src/lib/libcurses/curses.3:1.73	Thu Oct 25 10:36:56 2018
+++ src/lib/libcurses/curses.3	Mon Sep  2 09:08:29 2019
@@ -1,4 +1,4 @@
-.\"	$NetBSD: curses.3,v 1.73 2018/10/25 10:36:56 uwe Exp $
+.\"	$NetBSD: curses.3,v 1.74 2019/09/02 09:08:29 roy Exp $
 .\"
 .\" Copyright (c) 1985, 1991, 1993
 .\"	The Regents of the University of California.  All 

Re: CVS commit: src

2019-09-02 Thread Valery Ushakov
On Mon, Sep 02, 2019 at 09:08:29 +, Roy Marples wrote:

> curses(3): add curses_version()
> 
> Returns NetBSD-Curses %s
> Where %s is the NetBSD version taken from sys/param.h
> 
> Discussed on tech-net@, only for ncurses compat.

[This was on tech-userlevel@]

I know I'm late, but the patch on tech-userlevel was kinda misleading
as it used CURSES_VERSION in version.c and I didn't realize it was
actually the netbsd version from osrelease.sh. Committed code calls it
NETBSD_VERSION, which made me pay attention.

Why would we ever want to report this completely random and unrelated
fact?!

There were years when curses in the tree was unchanged.  In the mean
time we have churned through dozens of netbsd versions.

-uwe


CVS commit: src/share/misc

2019-09-02 Thread Sevan Janiyan
Module Name:src
Committed By:   sevan
Date:   Mon Sep  2 10:35:15 UTC 2019

Modified Files:
src/share/misc: acronyms.comp

Log Message:
PPT


To generate a diff of this commit:
cvs rdiff -u -r1.287 -r1.288 src/share/misc/acronyms.comp

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/misc/acronyms.comp
diff -u src/share/misc/acronyms.comp:1.287 src/share/misc/acronyms.comp:1.288
--- src/share/misc/acronyms.comp:1.287	Sun Sep  1 21:55:13 2019
+++ src/share/misc/acronyms.comp	Mon Sep  2 10:35:15 2019
@@ -1,4 +1,4 @@
-$NetBSD: acronyms.comp,v 1.287 2019/09/01 21:55:13 sevan Exp $
+$NetBSD: acronyms.comp,v 1.288 2019/09/02 10:35:15 sevan Exp $
 3WHS	three-way handshake
 8VSB	8-state vestigial side band modulation
 AA	anti-aliasing
@@ -1215,6 +1215,8 @@ PPP	Point-to-Point Protocol
 PPPOA	Point-to-Point Protocol over ATM
 PPPOE	Point-to-Point Protocol over Ethernet
 PPR	processor programming reference
+PPT	powerpoint
+PPT	punched paper tape
 PPU	physics processing unit
 PRAM	Parameter RAM
 PRBS	pseudorandom bit sequence



CVS commit: src/share/misc

2019-09-02 Thread Sevan Janiyan
Module Name:src
Committed By:   sevan
Date:   Mon Sep  2 10:35:15 UTC 2019

Modified Files:
src/share/misc: acronyms.comp

Log Message:
PPT


To generate a diff of this commit:
cvs rdiff -u -r1.287 -r1.288 src/share/misc/acronyms.comp

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/dev/sdmmc

2019-09-02 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Mon Sep  2 11:09:42 UTC 2019

Modified Files:
src/sys/dev/sdmmc: sdmmc_io.c

Log Message:
SD_IO_RW_EXTENDED is a data transfer command, so set ADTC flag instead of AC


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.16 src/sys/dev/sdmmc/sdmmc_io.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/sdmmc/sdmmc_io.c
diff -u src/sys/dev/sdmmc/sdmmc_io.c:1.15 src/sys/dev/sdmmc/sdmmc_io.c:1.16
--- src/sys/dev/sdmmc/sdmmc_io.c:1.15	Sun Sep  1 05:45:42 2019
+++ src/sys/dev/sdmmc/sdmmc_io.c	Mon Sep  2 11:09:42 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: sdmmc_io.c,v 1.15 2019/09/01 05:45:42 mlelstv Exp $	*/
+/*	$NetBSD: sdmmc_io.c,v 1.16 2019/09/02 11:09:42 jmcneill Exp $	*/
 /*	$OpenBSD: sdmmc_io.c,v 1.10 2007/09/17 01:33:33 krw Exp $	*/
 
 /*
@@ -20,7 +20,7 @@
 /* Routines for SD I/O cards. */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: sdmmc_io.c,v 1.15 2019/09/01 05:45:42 mlelstv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sdmmc_io.c,v 1.16 2019/09/02 11:09:42 jmcneill Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_sdmmc.h"
@@ -394,7 +394,7 @@ sdmmc_io_rw_extended(struct sdmmc_softc 
 	memset(, 0, sizeof cmd);
 	cmd.c_opcode = SD_IO_RW_EXTENDED;
 	cmd.c_arg = arg;
-	cmd.c_flags = SCF_CMD_AC | SCF_RSP_R5;
+	cmd.c_flags = SCF_CMD_ADTC | SCF_RSP_R5;
 	cmd.c_data = datap;
 	cmd.c_datalen = datalen;
 	cmd.c_blklen = MIN(datalen, sf->blklen);



CVS commit: src/sys/dev/sdmmc

2019-09-02 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Mon Sep  2 11:09:42 UTC 2019

Modified Files:
src/sys/dev/sdmmc: sdmmc_io.c

Log Message:
SD_IO_RW_EXTENDED is a data transfer command, so set ADTC flag instead of AC


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.16 src/sys/dev/sdmmc/sdmmc_io.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-9] src/doc

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 16:19:32 UTC 2019

Modified Files:
src/doc [netbsd-9]: CHANGES-9.0

Log Message:
Ticket #110


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.36 -r1.1.2.37 src/doc/CHANGES-9.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-9] src/doc

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 16:19:32 UTC 2019

Modified Files:
src/doc [netbsd-9]: CHANGES-9.0

Log Message:
Ticket #110


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.36 -r1.1.2.37 src/doc/CHANGES-9.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-9.0
diff -u src/doc/CHANGES-9.0:1.1.2.36 src/doc/CHANGES-9.0:1.1.2.37
--- src/doc/CHANGES-9.0:1.1.2.36	Mon Sep  2 07:07:21 2019
+++ src/doc/CHANGES-9.0	Mon Sep  2 16:19:32 2019
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-9.0,v 1.1.2.36 2019/09/02 07:07:21 martin Exp $
+# $NetBSD: CHANGES-9.0,v 1.1.2.37 2019/09/02 16:19:32 martin Exp $
 
 A complete list of changes from the initial NetBSD 9.0 branch on 2019-07-30
 until the 9.0 release:
@@ -2655,3 +2655,17 @@ share/man/man9/uiomove.9			1.19
 	Fix cross-references in these man-pages.
 	[oster, ticket #167]
 
+lib/libutil/getdiskrawname.c			1.6
+libexec/lfs_cleanerd/lfs_cleanerd.8		1.19
+libexec/lfs_cleanerd/lfs_cleanerd.c		1.59,1.60
+sbin/resize_lfs/resize_lfs.c			1.15
+tests/fs/common/fstest_lfs.c			1.7
+usr.sbin/puffs/rump_lfs/rump_lfs.c		1.19
+
+	Make ZFS and lfs interoperate:
+	Use getdiskrawname to find the device name.
+	Teach getdiskrawname and getdiskcookedname about zvols.
+	Also supply rope for rump based tests and use that to make the
+	lfs cleaner work properly in the test envrionment.
+	[brad, ticket #110]
+



Re: CVS commit: src

2019-09-02 Thread Taylor R Campbell
> Date: Mon, 2 Sep 2019 16:53:34 +0900
> From: Masanobu SAITOH 
> 
> d) Any other options.

1. Revert the commit for now, ASAP, to unblock people.

2. Deterministically transform the uppercase filenames into versions
   that do not collide under case folding with lowercase filenames.
   For example, FOO_bar.bin -> u_foo_bar.bin.

3. Change the Linux module firmware loading files to apply the
   transformation at run-time so we don't have to patch upstream code
   to cope with it.

4. Maybe ask upstream to change names so we can eliminate this hack in
   the future.


CVS commit: [netbsd-9] src

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 16:16:57 UTC 2019

Modified Files:
src/lib/libutil [netbsd-9]: getdiskrawname.c
src/libexec/lfs_cleanerd [netbsd-9]: lfs_cleanerd.8 lfs_cleanerd.c
src/sbin/resize_lfs [netbsd-9]: resize_lfs.c
src/tests/fs/common [netbsd-9]: fstest_lfs.c
src/usr.sbin/puffs/rump_lfs [netbsd-9]: rump_lfs.c

Log Message:
Pull up following revision(s) (requested by brad in ticket #110):

libexec/lfs_cleanerd/lfs_cleanerd.c: revision 1.59
libexec/lfs_cleanerd/lfs_cleanerd.8: revision 1.19
sbin/resize_lfs/resize_lfs.c: revision 1.15
usr.sbin/puffs/rump_lfs/rump_lfs.c: revision 1.19
libexec/lfs_cleanerd/lfs_cleanerd.c: revision 1.60
lib/libutil/getdiskrawname.c: revision 1.6
tests/fs/common/fstest_lfs.c: revision 1.7

Use getdiskrawname to find the device name.
Reviewed by Christos

 -

Teach getdiskrawname and getdiskcookedname about zvols.
Reviewed by Christos

 -

Add support for passing the raw device name separate from the
filesystem.  This is useful in the case where the cleaner is compiled
into code, such as rump_lfs and the ATF tests.  This helps to fix
bin/54488

 -

The cleaner is compiled into rump_lfs and executed as a thread.  Pass
in the raw device using the new -J option.  This avoids the use of
getdiskrawname which is not particularly rump safe in this context and
insures that the rump container device is used for cleaning, not the
outer device.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.5.18.1 src/lib/libutil/getdiskrawname.c
cvs rdiff -u -r1.18 -r1.18.48.1 src/libexec/lfs_cleanerd/lfs_cleanerd.8
cvs rdiff -u -r1.58 -r1.58.18.1 src/libexec/lfs_cleanerd/lfs_cleanerd.c
cvs rdiff -u -r1.14 -r1.14.18.1 src/sbin/resize_lfs/resize_lfs.c
cvs rdiff -u -r1.6 -r1.6.2.1 src/tests/fs/common/fstest_lfs.c
cvs rdiff -u -r1.18 -r1.18.18.1 src/usr.sbin/puffs/rump_lfs/rump_lfs.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-9] src

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 16:16:57 UTC 2019

Modified Files:
src/lib/libutil [netbsd-9]: getdiskrawname.c
src/libexec/lfs_cleanerd [netbsd-9]: lfs_cleanerd.8 lfs_cleanerd.c
src/sbin/resize_lfs [netbsd-9]: resize_lfs.c
src/tests/fs/common [netbsd-9]: fstest_lfs.c
src/usr.sbin/puffs/rump_lfs [netbsd-9]: rump_lfs.c

Log Message:
Pull up following revision(s) (requested by brad in ticket #110):

libexec/lfs_cleanerd/lfs_cleanerd.c: revision 1.59
libexec/lfs_cleanerd/lfs_cleanerd.8: revision 1.19
sbin/resize_lfs/resize_lfs.c: revision 1.15
usr.sbin/puffs/rump_lfs/rump_lfs.c: revision 1.19
libexec/lfs_cleanerd/lfs_cleanerd.c: revision 1.60
lib/libutil/getdiskrawname.c: revision 1.6
tests/fs/common/fstest_lfs.c: revision 1.7

Use getdiskrawname to find the device name.
Reviewed by Christos

 -

Teach getdiskrawname and getdiskcookedname about zvols.
Reviewed by Christos

 -

Add support for passing the raw device name separate from the
filesystem.  This is useful in the case where the cleaner is compiled
into code, such as rump_lfs and the ATF tests.  This helps to fix
bin/54488

 -

The cleaner is compiled into rump_lfs and executed as a thread.  Pass
in the raw device using the new -J option.  This avoids the use of
getdiskrawname which is not particularly rump safe in this context and
insures that the rump container device is used for cleaning, not the
outer device.


To generate a diff of this commit:
cvs rdiff -u -r1.5 -r1.5.18.1 src/lib/libutil/getdiskrawname.c
cvs rdiff -u -r1.18 -r1.18.48.1 src/libexec/lfs_cleanerd/lfs_cleanerd.8
cvs rdiff -u -r1.58 -r1.58.18.1 src/libexec/lfs_cleanerd/lfs_cleanerd.c
cvs rdiff -u -r1.14 -r1.14.18.1 src/sbin/resize_lfs/resize_lfs.c
cvs rdiff -u -r1.6 -r1.6.2.1 src/tests/fs/common/fstest_lfs.c
cvs rdiff -u -r1.18 -r1.18.18.1 src/usr.sbin/puffs/rump_lfs/rump_lfs.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libutil/getdiskrawname.c
diff -u src/lib/libutil/getdiskrawname.c:1.5 src/lib/libutil/getdiskrawname.c:1.5.18.1
--- src/lib/libutil/getdiskrawname.c:1.5	Wed Sep 17 23:54:42 2014
+++ src/lib/libutil/getdiskrawname.c	Mon Sep  2 16:16:56 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: getdiskrawname.c,v 1.5 2014/09/17 23:54:42 christos Exp $	*/
+/*	$NetBSD: getdiskrawname.c,v 1.5.18.1 2019/09/02 16:16:56 martin Exp $	*/
 
 /*-
  * Copyright (c) 2012 The NetBSD Foundation, Inc.
@@ -29,7 +29,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include 
-__RCSID("$NetBSD: getdiskrawname.c,v 1.5 2014/09/17 23:54:42 christos Exp $");
+__RCSID("$NetBSD: getdiskrawname.c,v 1.5.18.1 2019/09/02 16:16:56 martin Exp $");
 
 #include 
 
@@ -70,10 +70,74 @@ resolve_link(char *buf, size_t bufsiz, c
 	return buf;
 }
 
+/*
+ * zvol device names look like:
+ * /dev/zvol/dsk/pool_name/.../volume_name
+ * /dev/zvol/rdsk/pool_name/.../volume_name
+ *
+ * ZFS pools can be divided nearly to infinity
+ *
+ * This allows for 16 pool names, which one would hope would be enough
+ */
+#define DISKMAXPARTS 20
+static int
+calc_zvol_name(char *buf, size_t bufsiz, const char *name, const char *raw)
+{
+	char copyname[PATH_MAX];
+	char *names[DISKMAXPARTS];
+	char *last, *p;
+	size_t i = 0;
+
+	strlcpy(copyname, name, sizeof(copyname));
+	for (p = strtok_r(copyname, "/", ); p;
+	 p = strtok_r(NULL, "/", )) {
+		if (i >= DISKMAXPARTS) {
+			errno =  ENOSPC;
+			return -1;
+		}
+		names[i++] = p;
+	}
+
+	if (i < 4) {
+		errno = EINVAL;
+		return -1;
+	}
+
+	snprintf(buf, bufsiz, "/dev/zvol/%sdsk", raw);
+	for (size_t j = 3; j < i; j++) {
+		strlcat(buf, "/", bufsiz);
+		strlcat(buf, names[j], bufsiz);
+	}
+	return 0;
+}
+
+static int
+calc_name(char *buf, size_t bufsiz, const char *name, const char *raw)
+{
+	int skip = 1;
+
+	if (strncmp("/dev/zvol/", name, 10) == 0)
+		return calc_zvol_name(buf, bufsiz, name, raw);
+
+	const char *dp = strrchr(name, '/');
+	if (!*raw && ((dp != NULL && dp[1] != 'r')
+		|| (dp == NULL && name[0] != 'r'))) {
+		errno = EINVAL;
+		return -1;
+	}
+	if (raw[0] != 'r')
+		skip = 2;
+	if (dp != NULL)
+		snprintf(buf, bufsiz, "%.*s/%s%s", (int)(dp - name),
+		name, raw, dp + skip);
+	else
+		snprintf(buf, bufsiz, "%s%s", raw, name);
+	return 0;
+}
+
 const char *
 getdiskrawname(char *buf, size_t bufsiz, const char *name)
 {
-	const char *dp;
 	struct stat st;
 	char dest[PATH_MAX];
 
@@ -82,8 +146,6 @@ getdiskrawname(char *buf, size_t bufsiz,
 		return NULL;
 	}
 
-	dp = strrchr(name, '/');
-
 	if (stat(name, ) == -1)
 		return NULL;
 
@@ -92,10 +154,8 @@ getdiskrawname(char *buf, size_t bufsiz,
 		return NULL;
 	}
 
-	if (dp != NULL)
-		(void)snprintf(buf, bufsiz, "%.*s/r%s", (int)(dp - name), name, dp + 1);
-	else
-		(void)snprintf(buf, bufsiz, "r%s", name);
+	if (calc_name(buf, bufsiz, name, "r") == -1)
+		return NULL;
 
 	return buf;
 }
@@ -103,7 

CVS commit: src/sys/dev/mii

2019-09-02 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Mon Sep  2 12:48:52 UTC 2019

Modified Files:
src/sys/dev/mii: atphy.c

Log Message:
s/etphy/atphy/. No functional change.


To generate a diff of this commit:
cvs rdiff -u -r1.22 -r1.23 src/sys/dev/mii/atphy.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: src/sys/dev/mii

2019-09-02 Thread SAITOH Masanobu
Module Name:src
Committed By:   msaitoh
Date:   Mon Sep  2 12:48:52 UTC 2019

Modified Files:
src/sys/dev/mii: atphy.c

Log Message:
s/etphy/atphy/. No functional change.


To generate a diff of this commit:
cvs rdiff -u -r1.22 -r1.23 src/sys/dev/mii/atphy.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/mii/atphy.c
diff -u src/sys/dev/mii/atphy.c:1.22 src/sys/dev/mii/atphy.c:1.23
--- src/sys/dev/mii/atphy.c:1.22	Thu Apr 11 09:00:34 2019
+++ src/sys/dev/mii/atphy.c	Mon Sep  2 12:48:52 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: atphy.c,v 1.22 2019/04/11 09:00:34 msaitoh Exp $ */
+/*	$NetBSD: atphy.c,v 1.23 2019/09/02 12:48:52 msaitoh Exp $ */
 /*	$OpenBSD: atphy.c,v 1.1 2008/09/25 20:47:16 brad Exp $	*/
 
 /*-
@@ -33,7 +33,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: atphy.c,v 1.22 2019/04/11 09:00:34 msaitoh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: atphy.c,v 1.23 2019/09/02 12:48:52 msaitoh Exp $");
 
 #include 
 #include 
@@ -90,7 +90,7 @@ const struct mii_phy_funcs atphy_funcs =
 atphy_service, atphy_status, atphy_reset,
 };
 
-static const struct mii_phydesc etphys[] = {
+static const struct mii_phydesc atphys[] = {
 	MII_PHY_DESC(ATHEROS, F1),
 	MII_PHY_DESC(ATTANSIC, L1),
 	MII_PHY_DESC(ATTANSIC, L2),
@@ -118,7 +118,7 @@ atphy_match(device_t parent, cfdata_t ma
 {
 	struct mii_attach_args *ma = aux;
 
-	if (mii_phy_match(ma, etphys) != NULL)
+	if (mii_phy_match(ma, atphys) != NULL)
 		return 10;
 
 	return 0;
@@ -133,7 +133,7 @@ atphy_attach(device_t parent, device_t s
 	const struct mii_phydesc *mpd;
 	uint16_t bmsr;
 
-	mpd = mii_phy_match(ma, etphys);
+	mpd = mii_phy_match(ma, atphys);
 	aprint_naive(": Media interface\n");
 	aprint_normal(": %s, rev. %d\n", mpd->mpd_name, MII_REV(ma->mii_id2));
 



CVS commit: [netbsd-8] src/share/man

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 17:09:44 UTC 2019

Modified Files:
src/share/man/man1/man1.atari [netbsd-8]: edahdi.1 msconfig.1
src/share/man/man1/man1.x68k [netbsd-8]: aout2hux.1 bellctrl.1
loadfont.1 loadkmap.1 palette.1 tvctrl.1
src/share/man/man4 [netbsd-8]: null.4
src/share/man/man8/man8.next68k [netbsd-8]: boot.8
src/share/man/man9 [netbsd-8]: arp.9

Log Message:
Pull up following revision(s) (requested by sevan in tickets
 #1352 - #1364):

share/man/man1/man1.x68k/tvctrl.1: revision 1.6
share/man/man1/man1.x68k/aout2hux.1: revision 1.6
share/man/man1/man1.x68k/palette.1: revision 1.7
share/man/man9/arp.9: revision 1.27
share/man/man1/man1.atari/edahdi.1: revision 1.12
share/man/man1/man1.x68k/loadkmap.1: revision 1.7
share/man/man1/man1.atari/msconfig.1: revision 1.9
share/man/man1/man1.x68k/bellctrl.1: revision 1.16
share/man/man1/man1.x68k/bellctrl.1: revision 1.17
share/man/man4/null.4: revision 1.5
share/man/man4/null.4: revision 1.6
share/man/man1/man1.x68k/loadfont.1: revision 1.10
share/man/man8/man8.next68k/boot.8: revision 1.5

Provide history.
Improve grammar and readability. Minor cosmetics.
Update arpresolve arguments


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.11.38.1 src/share/man/man1/man1.atari/edahdi.1
cvs rdiff -u -r1.8 -r1.8.38.1 src/share/man/man1/man1.atari/msconfig.1
cvs rdiff -u -r1.5 -r1.5.92.1 src/share/man/man1/man1.x68k/aout2hux.1 \
src/share/man/man1/man1.x68k/tvctrl.1
cvs rdiff -u -r1.13.22.1 -r1.13.22.2 src/share/man/man1/man1.x68k/bellctrl.1
cvs rdiff -u -r1.9 -r1.9.92.1 src/share/man/man1/man1.x68k/loadfont.1
cvs rdiff -u -r1.6 -r1.6.92.1 src/share/man/man1/man1.x68k/loadkmap.1 \
src/share/man/man1/man1.x68k/palette.1
cvs rdiff -u -r1.4 -r1.4.92.1 src/share/man/man4/null.4
cvs rdiff -u -r1.4 -r1.4.52.1 src/share/man/man8/man8.next68k/boot.8
cvs rdiff -u -r1.26 -r1.26.18.1 src/share/man/man9/arp.9

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man1/man1.atari/edahdi.1
diff -u src/share/man/man1/man1.atari/edahdi.1:1.11 src/share/man/man1/man1.atari/edahdi.1:1.11.38.1
--- src/share/man/man1/man1.atari/edahdi.1:1.11	Tue Oct 20 19:10:10 2009
+++ src/share/man/man1/man1.atari/edahdi.1	Mon Sep  2 17:09:43 2019
@@ -1,4 +1,4 @@
-.\"	$NetBSD: edahdi.1,v 1.11 2009/10/20 19:10:10 snj Exp $
+.\"	$NetBSD: edahdi.1,v 1.11.38.1 2019/09/02 17:09:43 martin Exp $
 .\"
 .\" Copyright (c) 1996 Leo Weppelman
 .\" All rights reserved.
@@ -23,7 +23,7 @@
 .\" (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 .\" THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 .\"
-.Dd May 16, 1996
+.Dd September 1, 2019
 .Dt EDAHDI 1 atari
 .Os
 .Sh NAME
@@ -35,16 +35,16 @@
 .Sh DESCRIPTION
 .Nm
 allows you to modify the partition identifiers on a disk partitioned with
-AHDI or an AHDI compatible formatter. An AHDI partition format is usually
-only present on disks shared between
+AHDI or an AHDI compatible formatter.
+An AHDI partition format is usually only present on disks shared between
 .Nx
-and some other OS. The partition identifiers are used by
+and some other OS.
+The partition identifiers are used by
 .Nx
 as a guideline to emulate a disklabel on such a disk.
 .Pp
 .Nm
 supports the following options:
-.Pp
 .Bl -tag -width device
 .It Ar device
 The name of the raw device you want to edit.
@@ -52,13 +52,12 @@ The name of the raw device you want to e
 .Pp
 The following partition identifiers are recognized by
 .Nx :
-.Pp
 .Bl -tag -width "GEM or BGM" -compact
 .It NBD
 Partition is reserved for
 .Nx .
-This can be either a root or an user partition. The first NBD
-partition on a disk will be mapped to partition
+This can be either a root or an user partition.
+The first NBD partition on a disk will be mapped to partition
 .Em a
 in
 .Nx .
@@ -72,7 +71,8 @@ The first SWP partition is mapped to par
 .It GEM or BGM
 These partitions are mapped from
 .Em d
-up. The filesystem type is msdos.
+up.
+The filesystem type is msdos.
 .It NBR
 .Nx
 root partition (deprecated).
@@ -84,8 +84,7 @@ user partition (deprecated).
 swap partition (deprecated).
 .El
 .Sh EXAMPLES
-Say, you have a disk with that is partitioned like:
-.Pp
+Say, you have a disk that is partitioned like:
 .Bl -column Number   Id
 .It Sy "Number" Ta Sy "Id"
 .It 1 Ta GEM
@@ -97,7 +96,6 @@ Say, you have a disk with that is partit
 This partitioning will show up in
 .Nx
 as (Number refers to the first table):
-.Pp
 .Bl -column "c (whole disk)" "Fstype" "Number"
 .It Sy Partition Ta Sy Fstype Ta Sy Number
 .It c (whole disk) Ta unused Ta ""
@@ -107,10 +105,10 @@ as (Number refers to the first table):
 .It g (user part) Ta MSDOS Ta 4
 .El
 .Pp
-Now you decide to change the id of 

CVS commit: [netbsd-8] src/share/man

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 17:09:44 UTC 2019

Modified Files:
src/share/man/man1/man1.atari [netbsd-8]: edahdi.1 msconfig.1
src/share/man/man1/man1.x68k [netbsd-8]: aout2hux.1 bellctrl.1
loadfont.1 loadkmap.1 palette.1 tvctrl.1
src/share/man/man4 [netbsd-8]: null.4
src/share/man/man8/man8.next68k [netbsd-8]: boot.8
src/share/man/man9 [netbsd-8]: arp.9

Log Message:
Pull up following revision(s) (requested by sevan in tickets
 #1352 - #1364):

share/man/man1/man1.x68k/tvctrl.1: revision 1.6
share/man/man1/man1.x68k/aout2hux.1: revision 1.6
share/man/man1/man1.x68k/palette.1: revision 1.7
share/man/man9/arp.9: revision 1.27
share/man/man1/man1.atari/edahdi.1: revision 1.12
share/man/man1/man1.x68k/loadkmap.1: revision 1.7
share/man/man1/man1.atari/msconfig.1: revision 1.9
share/man/man1/man1.x68k/bellctrl.1: revision 1.16
share/man/man1/man1.x68k/bellctrl.1: revision 1.17
share/man/man4/null.4: revision 1.5
share/man/man4/null.4: revision 1.6
share/man/man1/man1.x68k/loadfont.1: revision 1.10
share/man/man8/man8.next68k/boot.8: revision 1.5

Provide history.
Improve grammar and readability. Minor cosmetics.
Update arpresolve arguments


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.11.38.1 src/share/man/man1/man1.atari/edahdi.1
cvs rdiff -u -r1.8 -r1.8.38.1 src/share/man/man1/man1.atari/msconfig.1
cvs rdiff -u -r1.5 -r1.5.92.1 src/share/man/man1/man1.x68k/aout2hux.1 \
src/share/man/man1/man1.x68k/tvctrl.1
cvs rdiff -u -r1.13.22.1 -r1.13.22.2 src/share/man/man1/man1.x68k/bellctrl.1
cvs rdiff -u -r1.9 -r1.9.92.1 src/share/man/man1/man1.x68k/loadfont.1
cvs rdiff -u -r1.6 -r1.6.92.1 src/share/man/man1/man1.x68k/loadkmap.1 \
src/share/man/man1/man1.x68k/palette.1
cvs rdiff -u -r1.4 -r1.4.92.1 src/share/man/man4/null.4
cvs rdiff -u -r1.4 -r1.4.52.1 src/share/man/man8/man8.next68k/boot.8
cvs rdiff -u -r1.26 -r1.26.18.1 src/share/man/man9/arp.9

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-9] src/share/man

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 17:17:12 UTC 2019

Modified Files:
src/share/man/man1/man1.atari [netbsd-9]: edahdi.1 msconfig.1
src/share/man/man1/man1.x68k [netbsd-9]: aout2hux.1 bellctrl.1
loadfont.1 loadkmap.1 palette.1 tvctrl.1
src/share/man/man4 [netbsd-9]: null.4
src/share/man/man8/man8.next68k [netbsd-9]: boot.8
src/share/man/man9 [netbsd-9]: arp.9

Log Message:
Pull up following revision(s) (requested by sevan in tickets
 #154 - #164):

share/man/man1/man1.x68k/tvctrl.1: revision 1.6
share/man/man1/man1.x68k/aout2hux.1: revision 1.6
share/man/man1/man1.x68k/palette.1: revision 1.7
share/man/man9/arp.9: revision 1.27
share/man/man1/man1.atari/edahdi.1: revision 1.12
share/man/man1/man1.x68k/loadkmap.1: revision 1.7
share/man/man1/man1.atari/msconfig.1: revision 1.9
share/man/man1/man1.x68k/bellctrl.1: revision 1.16
share/man/man1/man1.x68k/bellctrl.1: revision 1.17
share/man/man4/null.4: revision 1.5
share/man/man4/null.4: revision 1.6
share/man/man1/man1.x68k/loadfont.1: revision 1.10
share/man/man8/man8.next68k/boot.8: revision 1.5

Provide history.
Improve grammar and readability. Minor cosmetics.
Update arpresolve arguments


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.11.48.1 src/share/man/man1/man1.atari/edahdi.1
cvs rdiff -u -r1.8 -r1.8.48.1 src/share/man/man1/man1.atari/msconfig.1
cvs rdiff -u -r1.5 -r1.5.102.1 src/share/man/man1/man1.x68k/aout2hux.1 \
src/share/man/man1/man1.x68k/tvctrl.1
cvs rdiff -u -r1.15 -r1.15.8.1 src/share/man/man1/man1.x68k/bellctrl.1
cvs rdiff -u -r1.9 -r1.9.102.1 src/share/man/man1/man1.x68k/loadfont.1
cvs rdiff -u -r1.6 -r1.6.102.1 src/share/man/man1/man1.x68k/loadkmap.1 \
src/share/man/man1/man1.x68k/palette.1
cvs rdiff -u -r1.4 -r1.4.102.1 src/share/man/man4/null.4
cvs rdiff -u -r1.4 -r1.4.62.1 src/share/man/man8/man8.next68k/boot.8
cvs rdiff -u -r1.26 -r1.26.28.1 src/share/man/man9/arp.9

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man1/man1.atari/edahdi.1
diff -u src/share/man/man1/man1.atari/edahdi.1:1.11 src/share/man/man1/man1.atari/edahdi.1:1.11.48.1
--- src/share/man/man1/man1.atari/edahdi.1:1.11	Tue Oct 20 19:10:10 2009
+++ src/share/man/man1/man1.atari/edahdi.1	Mon Sep  2 17:17:12 2019
@@ -1,4 +1,4 @@
-.\"	$NetBSD: edahdi.1,v 1.11 2009/10/20 19:10:10 snj Exp $
+.\"	$NetBSD: edahdi.1,v 1.11.48.1 2019/09/02 17:17:12 martin Exp $
 .\"
 .\" Copyright (c) 1996 Leo Weppelman
 .\" All rights reserved.
@@ -23,7 +23,7 @@
 .\" (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 .\" THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 .\"
-.Dd May 16, 1996
+.Dd September 1, 2019
 .Dt EDAHDI 1 atari
 .Os
 .Sh NAME
@@ -35,16 +35,16 @@
 .Sh DESCRIPTION
 .Nm
 allows you to modify the partition identifiers on a disk partitioned with
-AHDI or an AHDI compatible formatter. An AHDI partition format is usually
-only present on disks shared between
+AHDI or an AHDI compatible formatter.
+An AHDI partition format is usually only present on disks shared between
 .Nx
-and some other OS. The partition identifiers are used by
+and some other OS.
+The partition identifiers are used by
 .Nx
 as a guideline to emulate a disklabel on such a disk.
 .Pp
 .Nm
 supports the following options:
-.Pp
 .Bl -tag -width device
 .It Ar device
 The name of the raw device you want to edit.
@@ -52,13 +52,12 @@ The name of the raw device you want to e
 .Pp
 The following partition identifiers are recognized by
 .Nx :
-.Pp
 .Bl -tag -width "GEM or BGM" -compact
 .It NBD
 Partition is reserved for
 .Nx .
-This can be either a root or an user partition. The first NBD
-partition on a disk will be mapped to partition
+This can be either a root or an user partition.
+The first NBD partition on a disk will be mapped to partition
 .Em a
 in
 .Nx .
@@ -72,7 +71,8 @@ The first SWP partition is mapped to par
 .It GEM or BGM
 These partitions are mapped from
 .Em d
-up. The filesystem type is msdos.
+up.
+The filesystem type is msdos.
 .It NBR
 .Nx
 root partition (deprecated).
@@ -84,8 +84,7 @@ user partition (deprecated).
 swap partition (deprecated).
 .El
 .Sh EXAMPLES
-Say, you have a disk with that is partitioned like:
-.Pp
+Say, you have a disk that is partitioned like:
 .Bl -column Number   Id
 .It Sy "Number" Ta Sy "Id"
 .It 1 Ta GEM
@@ -97,7 +96,6 @@ Say, you have a disk with that is partit
 This partitioning will show up in
 .Nx
 as (Number refers to the first table):
-.Pp
 .Bl -column "c (whole disk)" "Fstype" "Number"
 .It Sy Partition Ta Sy Fstype Ta Sy Number
 .It c (whole disk) Ta unused Ta ""
@@ -107,10 +105,10 @@ as (Number refers to the first table):
 .It g (user part) Ta MSDOS Ta 4
 .El
 .Pp
-Now you decide to change the id of partition 

CVS commit: [netbsd-9] src/share/man

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 17:17:12 UTC 2019

Modified Files:
src/share/man/man1/man1.atari [netbsd-9]: edahdi.1 msconfig.1
src/share/man/man1/man1.x68k [netbsd-9]: aout2hux.1 bellctrl.1
loadfont.1 loadkmap.1 palette.1 tvctrl.1
src/share/man/man4 [netbsd-9]: null.4
src/share/man/man8/man8.next68k [netbsd-9]: boot.8
src/share/man/man9 [netbsd-9]: arp.9

Log Message:
Pull up following revision(s) (requested by sevan in tickets
 #154 - #164):

share/man/man1/man1.x68k/tvctrl.1: revision 1.6
share/man/man1/man1.x68k/aout2hux.1: revision 1.6
share/man/man1/man1.x68k/palette.1: revision 1.7
share/man/man9/arp.9: revision 1.27
share/man/man1/man1.atari/edahdi.1: revision 1.12
share/man/man1/man1.x68k/loadkmap.1: revision 1.7
share/man/man1/man1.atari/msconfig.1: revision 1.9
share/man/man1/man1.x68k/bellctrl.1: revision 1.16
share/man/man1/man1.x68k/bellctrl.1: revision 1.17
share/man/man4/null.4: revision 1.5
share/man/man4/null.4: revision 1.6
share/man/man1/man1.x68k/loadfont.1: revision 1.10
share/man/man8/man8.next68k/boot.8: revision 1.5

Provide history.
Improve grammar and readability. Minor cosmetics.
Update arpresolve arguments


To generate a diff of this commit:
cvs rdiff -u -r1.11 -r1.11.48.1 src/share/man/man1/man1.atari/edahdi.1
cvs rdiff -u -r1.8 -r1.8.48.1 src/share/man/man1/man1.atari/msconfig.1
cvs rdiff -u -r1.5 -r1.5.102.1 src/share/man/man1/man1.x68k/aout2hux.1 \
src/share/man/man1/man1.x68k/tvctrl.1
cvs rdiff -u -r1.15 -r1.15.8.1 src/share/man/man1/man1.x68k/bellctrl.1
cvs rdiff -u -r1.9 -r1.9.102.1 src/share/man/man1/man1.x68k/loadfont.1
cvs rdiff -u -r1.6 -r1.6.102.1 src/share/man/man1/man1.x68k/loadkmap.1 \
src/share/man/man1/man1.x68k/palette.1
cvs rdiff -u -r1.4 -r1.4.102.1 src/share/man/man4/null.4
cvs rdiff -u -r1.4 -r1.4.62.1 src/share/man/man8/man8.next68k/boot.8
cvs rdiff -u -r1.26 -r1.26.28.1 src/share/man/man9/arp.9

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-9] src/doc

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 17:28:28 UTC 2019

Modified Files:
src/doc [netbsd-9]: CHANGES-9.0

Log Message:
Tickets #154 - #164


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.37 -r1.1.2.38 src/doc/CHANGES-9.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-9] src/doc

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 17:28:28 UTC 2019

Modified Files:
src/doc [netbsd-9]: CHANGES-9.0

Log Message:
Tickets #154 - #164


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.37 -r1.1.2.38 src/doc/CHANGES-9.0

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-9.0
diff -u src/doc/CHANGES-9.0:1.1.2.37 src/doc/CHANGES-9.0:1.1.2.38
--- src/doc/CHANGES-9.0:1.1.2.37	Mon Sep  2 16:19:32 2019
+++ src/doc/CHANGES-9.0	Mon Sep  2 17:28:28 2019
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-9.0,v 1.1.2.37 2019/09/02 16:19:32 martin Exp $
+# $NetBSD: CHANGES-9.0,v 1.1.2.38 2019/09/02 17:28:28 martin Exp $
 
 A complete list of changes from the initial NetBSD 9.0 branch on 2019-07-30
 until the 9.0 release:
@@ -2669,3 +2669,20 @@ usr.sbin/puffs/rump_lfs/rump_lfs.c		1.19
 	lfs cleaner work properly in the test envrionment.
 	[brad, ticket #110]
 
+share/man/man1/man1.atari/edahdi.1		1.12
+share/man/man1/man1.atari/msconfig.1		1.9
+share/man/man1/man1.x68k/aout2hux.1		1.6
+share/man/man1/man1.x68k/bellctrl.1		1.16
+share/man/man1/man1.x68k/bellctrl.1		1.17
+share/man/man1/man1.x68k/loadfont.1		1.10
+share/man/man1/man1.x68k/loadkmap.1		1.7
+share/man/man1/man1.x68k/palette.1		1.7
+share/man/man1/man1.x68k/tvctrl.1		1.6
+share/man/man4/null.41.5,1.6
+share/man/man8/man8.next68k/boot.8		1.5
+share/man/man9/arp.91.27
+
+	Provide history.
+	Improve grammar and readability. Minor cosmetics.
+	[sevan, tickets #154 - #164]
+



CVS commit: [netbsd-8] src/share/man

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 16:39:25 UTC 2019

Modified Files:
src/share/man/man1 [netbsd-8]: cd.1 wait.1
src/share/man/man1/man1.x68k [netbsd-8]: bellctrl.1
src/share/man/man3 [netbsd-8]: __arraycount.3 bitmap.3 bits.3
bitstring.3 fast_divide32.3 gcq.3 iso646.3 queue.3 tree.3
src/share/man/man4 [netbsd-8]: acpilid.4 agp.4 ahc.4 ahd.4 ai.4 amr.4
ath.4 audio.4 bio.4 bluetooth.4 bpf.4 btsco.4 cfb.4 chipsfb.4
cmpci.4 crypto.4 ddb.4 dge.4 ec.4 edc.4 envsys.4 etherip.4
gpiosim.4 gre.4 ieee80211.4 iop.4 ip.4 ip6.4 isa.4 isdntel.4 isic.4
jme.4 mfb.4 mfi.4 midi.4 mpls.4 multicast.4 options.4 pad.4 pci.4
pim.4 plip.4 pppoe.4 radio.4 ral.4 route.4 sc.4 se.4 si.4 strip.4
termios.4 uftdi.4 ugen.4 unix.4 usb.4 userconf.4 utoppy.4 uyurex.4
we.4 ym.4 zyd.4
src/share/man/man4/man4.alpha [netbsd-8]: ttwoga.4 ttwopci.4
src/share/man/man4/man4.amiga [netbsd-8]: grf.4 mfcs.4
src/share/man/man4/man4.atari [netbsd-8]: rtc.4
src/share/man/man4/man4.dreamcast [netbsd-8]: aica.4
src/share/man/man4/man4.hp300 [netbsd-8]: dcl.4
src/share/man/man4/man4.hppa [netbsd-8]: pdc.4
src/share/man/man4/man4.i386 [netbsd-8]: intro.4 ndis.4 pcibios.4
src/share/man/man4/man4.sgimips [netbsd-8]: giopci.4
src/share/man/man4/man4.sparc [netbsd-8]: intro.4 magma.4
src/share/man/man4/man4.sparc64 [netbsd-8]: intro.4
src/share/man/man4/man4.sun2 [netbsd-8]: leds.4
src/share/man/man4/man4.sun3 [netbsd-8]: leds.4
src/share/man/man4/man4.vax [netbsd-8]: ad.4 cons.4 dl.4 dn.4 hy.4 ix.4
src/share/man/man5 [netbsd-8]: ar.5 boot.cfg.5 capfile.5 core.5
genassym.cf.5 ld.so.conf.5 link.5 locale.alias.5 mixerctl.conf.5
nsswitch.conf.5 passwd.5 passwd.conf.5 ranlib.5 stab.5 veriexec.5
src/share/man/man7 [netbsd-8]: ascii.7 hier.7 operator.7 release.7
security.7 sysctl.7
src/share/man/man8 [netbsd-8]: afterboot.8 compat_freebsd.8
compat_linux.8 compat_sunos.8 compat_svr4.8 compat_ultrix.8
diskless.8 sysinst.8
src/share/man/man8/man8.acorn26 [netbsd-8]: boot26.8
src/share/man/man8/man8.alpha [netbsd-8]: boot.8 mkbootimage.8
src/share/man/man8/man8.amiga [netbsd-8]: installboot.8
src/share/man/man8/man8.atari [netbsd-8]: ahdilabel.8
src/share/man/man8/man8.cobalt [netbsd-8]: boot.8
src/share/man/man8/man8.hppa [netbsd-8]: boot.8
src/share/man/man8/man8.macppc [netbsd-8]: boot.8 ofwboot.8
src/share/man/man8/man8.mvme68k [netbsd-8]: boot.8
src/share/man/man8/man8.sparc [netbsd-8]: boot.8
src/share/man/man8/man8.vax [netbsd-8]: boot.8 drtest.8 format.8
src/share/man/man8/man8.x86 [netbsd-8]: boot.8 mbr.8
src/share/man/man9/man9.i386 [netbsd-8]: bioscall.9

Log Message:
Pull up following revision(s) (requested by sevan in ticket #1351):

share/man/man4/man4.amiga/grf.4: revision 1.7
share/man/man4/si.4: revision 1.11
share/man/man8/man8.sparc/boot.8: revision 1.32
share/man/man5/nsswitch.conf.5: revision 1.29
share/man/man5/mixerctl.conf.5: revision 1.7
share/man/man8/man8.vax/boot.8: revision 1.14
share/man/man4/man4.vax/dn.4: revision 1.12
share/man/man8/man8.vax/drtest.8: revision 1.16
share/man/man8/sysinst.8: revision 1.6
share/man/man4/ip.4: revision 1.37
share/man/man5/boot.cfg.5: revision 1.28
share/man/man1/cd.1: revision 1.10
share/man/man4/usb.4: revision 1.106
share/man/man4/man4.vax/ix.4: revision 1.17
share/man/man7/security.7: revision 1.15
share/man/man7/hier.7: revision 1.123
share/man/man8/afterboot.8: revision 1.58
share/man/man1/man1.x68k/bellctrl.1: revision 1.14
share/man/man4/se.4: revision 1.6
share/man/man4/utoppy.4: revision 1.7
share/man/man4/midi.4: revision 1.32
share/man/man4/cfb.4: revision 1.5
share/man/man4/man4.sparc/magma.4: revision 1.12
share/man/man4/audio.4: revision 1.80
share/man/man4/isic.4: revision 1.18
share/man/man1/cd.1: revision 1.7
share/man/man4/envsys.4: revision 1.51
share/man/man1/cd.1: revision 1.8
share/man/man1/cd.1: revision 1.9
share/man/man3/fast_divide32.3: revision 1.9
share/man/man4/pci.4: revision 1.97
share/man/man5/ranlib.5: revision 1.7
share/man/man3/__arraycount.3: revision 1.7
share/man/man4/isa.4: revision 1.46
share/man/man8/man8.atari/ahdilabel.8: revision 1.14
share/man/man4/chipsfb.4: revision 1.6
share/man/man8/man8.macppc/boot.8: revision 1.8
share/man/man5/passwd.5: revision 1.33
share/man/man8/man8.macppc/ofwboot.8: revision 1.14

CVS commit: [netbsd-8] src/doc

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 17:20:47 UTC 2019

Modified Files:
src/doc [netbsd-8]: CHANGES-8.2

Log Message:
Tickets #1351 - #1364


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.31 -r1.1.2.32 src/doc/CHANGES-8.2

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.



CVS commit: [netbsd-8] src/doc

2019-09-02 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Mon Sep  2 17:20:47 UTC 2019

Modified Files:
src/doc [netbsd-8]: CHANGES-8.2

Log Message:
Tickets #1351 - #1364


To generate a diff of this commit:
cvs rdiff -u -r1.1.2.31 -r1.1.2.32 src/doc/CHANGES-8.2

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/doc/CHANGES-8.2
diff -u src/doc/CHANGES-8.2:1.1.2.31 src/doc/CHANGES-8.2:1.1.2.32
--- src/doc/CHANGES-8.2:1.1.2.31	Sun Sep  1 17:15:34 2019
+++ src/doc/CHANGES-8.2	Mon Sep  2 17:20:47 2019
@@ -1,4 +1,4 @@
-# $NetBSD: CHANGES-8.2,v 1.1.2.31 2019/09/01 17:15:34 martin Exp $
+# $NetBSD: CHANGES-8.2,v 1.1.2.32 2019/09/02 17:20:47 martin Exp $
 
 A complete list of changes from the NetBSD 8.1 release to the NetBSD 8.2
 release:
@@ -657,3 +657,174 @@ sys/dev/mii/ciphyreg.h1.6
 	- KNF.
 	[msaitoh, ticket #1350]
 
+share/man/man1/cd.11.7-1.10
+share/man/man1/man1.x68k/bellctrl.1		1.14
+share/man/man1/wait.11.5
+share/man/man3/__arraycount.3			1.7
+share/man/man3/bitmap.31.10
+share/man/man3/bits.31.18
+share/man/man3/bitstring.3			1.18
+share/man/man3/fast_divide32.3			1.9
+share/man/man3/gcq.31.4
+share/man/man3/iso646.31.6
+share/man/man3/queue.31.57
+share/man/man3/tree.31.12
+share/man/man4/acpilid.4			1.8
+share/man/man4/agp.41.17
+share/man/man4/ahc.41.34
+share/man/man4/ahd.41.6
+share/man/man4/ai.41.9
+share/man/man4/amr.41.15
+share/man/man4/ath.41.32
+share/man/man4/audio.41.80
+share/man/man4/bio.41.13
+share/man/man4/bluetooth.4			1.20
+share/man/man4/bpf.41.56
+share/man/man4/btsco.41.13
+share/man/man4/cfb.41.5
+share/man/man4/chipsfb.4			1.6
+share/man/man4/cmpci.41.9
+share/man/man4/crypto.41.26
+share/man/man4/ddb.41.167
+share/man/man4/dge.41.11
+share/man/man4/ec.41.14
+share/man/man4/edc.41.12
+share/man/man4/envsys.41.51
+share/man/man4/etherip.4			1.8
+share/man/man4/gpiosim.4			1.6
+share/man/man4/gre.41.45
+share/man/man4/ieee80211.4			1.5
+share/man/man4/iop.41.22
+share/man/man4/ip.41.37
+share/man/man4/ip6.41.31
+share/man/man4/isa.41.46
+share/man/man4/isdntel.4			1.8
+share/man/man4/isic.41.18
+share/man/man4/jme.41.7
+share/man/man4/man4.alpha/ttwoga.4		1.6
+share/man/man4/man4.alpha/ttwopci.4		1.6
+share/man/man4/man4.amiga/grf.4			1.7
+share/man/man4/man4.amiga/mfcs.4		1.8
+share/man/man4/man4.atari/rtc.4			1.8
+share/man/man4/man4.dreamcast/aica.4		1.6
+share/man/man4/man4.hp300/dcl.4			1.13
+share/man/man4/man4.hppa/pdc.4			1.3
+share/man/man4/man4.i386/intro.4		1.31
+share/man/man4/man4.i386/ndis.4			1.6
+share/man/man4/man4.i386/pcibios.4		1.19
+share/man/man4/man4.sgimips/giopci.4		1.9
+share/man/man4/man4.sparc/intro.4		1.27
+share/man/man4/man4.sparc/magma.4		1.12
+share/man/man4/man4.sparc64/intro.4		1.5
+share/man/man4/man4.sun2/leds.4			1.10
+share/man/man4/man4.sun3/leds.4			1.13
+share/man/man4/man4.vax/ad.4			1.12
+share/man/man4/man4.vax/cons.4			1.12
+share/man/man4/man4.vax/dl.4			1.13
+share/man/man4/man4.vax/dn.4			1.12
+share/man/man4/man4.vax/hy.4			1.12
+share/man/man4/man4.vax/ix.4			1.17
+share/man/man4/mfb.41.5
+share/man/man4/mfi.41.12
+share/man/man4/midi.41.32
+share/man/man4/mpls.41.10
+share/man/man4/multicast.4			1.8
+share/man/man4/options.4			1.467
+share/man/man4/pad.41.6
+share/man/man4/pci.41.97
+share/man/man4/pim.41.5
+share/man/man4/plip.41.4
+share/man/man4/pppoe.41.39
+share/man/man4/radio.41.13
+share/man/man4/ral.41.12
+share/man/man4/route.41.31
+share/man/man4/sc.41.8
+share/man/man4/se.41.6
+share/man/man4/si.41.11
+share/man/man4/strip.41.16
+share/man/man4/termios.4			1.37
+share/man/man4/uftdi.41.20
+share/man/man4/ugen.41.32
+share/man/man4/unix.41.26
+share/man/man4/usb.41.106
+share/man/man4/userconf.4			1.13
+share/man/man4/utoppy.41.7
+share/man/man4/uyurex.41.6
+share/man/man4/we.41.19
+share/man/man4/ym.41.19
+share/man/man4/zyd.41.5
+share/man/man5/ar.51.9
+share/man/man5/boot.cfg.5			1.28
+share/man/man5/capfile.5			1.4
+share/man/man5/core.51.31
+share/man/man5/genassym.cf.5			1.13
+share/man/man5/ld.so.conf.5			1.21
+share/man/man5/link.51.24
+share/man/man5/locale.alias.5			1.3
+share/man/man5/mixerctl.conf.5			1.7
+share/man/man5/nsswitch.conf.5			1.29
+share/man/man5/passwd.51.33
+share/man/man5/passwd.conf.5			1.11
+share/man/man5/ranlib.51.7
+share/man/man5/stab.51.15
+share/man/man5/veriexec.5			1.8
+share/man/man7/ascii.71.8
+share/man/man7/hier.71.123
+share/man/man7/operator.7			1.12
+share/man/man7/release.7			1.37
+share/man/man7/security.7			1.15
+share/man/man7/sysctl.71.114
+share/man/man8/afterboot.8			1.58
+share/man/man8/compat_freebsd.8			1.18
+share/man/man8/compat_linux.8			1.38
+share/man/man8/compat_sunos.8			1.21

CVS commit: src/sys

2019-09-02 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Mon Sep  2 20:09:30 UTC 2019

Modified Files:
src/sys/conf: files
src/sys/dev: rndpseudo.c
src/sys/kern: subr_cprng.c
src/sys/rump/kern/lib/libcrypto: Makefile
src/sys/rump/librump/rumpkern: Makefile.rumpkern
src/sys/sys: cprng.h
Added Files:
src/sys/crypto/nist_hash_drbg: files.nist_hash_drbg nist_hash_drbg.c
nist_hash_drbg.h
Removed Files:
src/sys/crypto/nist_ctr_drbg: files.nist_ctr_drbg
nist_ctr_aes_rijndael.h nist_ctr_drbg.c nist_ctr_drbg.h
nist_ctr_drbg_aes128.h nist_ctr_drbg_aes256.h
nist_ctr_drbg_config.h

Log Message:
Switch from NIST CTR_DRBG with AES to NIST Hash_DRBG with SHA-256.

Benefits:

- larger seeds -- a 128-bit key alone is not enough for `128-bit security'
- better resistance to timing side channels than AES
- a better-understood security story (https://eprint.iacr.org/2018/349)
- no loss in compliance with US government standards that nobody ever
  got fired for choosing, at least in the US-dominated western world
- no dirty endianness tricks
- self-tests

Drawbacks:

- performance hit: throughput is reduced to about 1/3 in naive measurements
  => possible to mitigate by using hardware SHA-256 instructions
  => all you really need is 32 bytes to seed a userland PRNG anyway
  => if we just used ChaCha this would go away...

XXX pullup-7
XXX pullup-8
XXX pullup-9


To generate a diff of this commit:
cvs rdiff -u -r1.1237 -r1.1238 src/sys/conf/files
cvs rdiff -u -r1.1 -r0 src/sys/crypto/nist_ctr_drbg/files.nist_ctr_drbg \
src/sys/crypto/nist_ctr_drbg/nist_ctr_drbg.c \
src/sys/crypto/nist_ctr_drbg/nist_ctr_drbg_config.h
cvs rdiff -u -r1.2 -r0 src/sys/crypto/nist_ctr_drbg/nist_ctr_aes_rijndael.h \
src/sys/crypto/nist_ctr_drbg/nist_ctr_drbg_aes128.h \
src/sys/crypto/nist_ctr_drbg/nist_ctr_drbg_aes256.h
cvs rdiff -u -r1.3 -r0 src/sys/crypto/nist_ctr_drbg/nist_ctr_drbg.h
cvs rdiff -u -r0 -r1.1 src/sys/crypto/nist_hash_drbg/files.nist_hash_drbg \
src/sys/crypto/nist_hash_drbg/nist_hash_drbg.c \
src/sys/crypto/nist_hash_drbg/nist_hash_drbg.h
cvs rdiff -u -r1.37 -r1.38 src/sys/dev/rndpseudo.c
cvs rdiff -u -r1.30 -r1.31 src/sys/kern/subr_cprng.c
cvs rdiff -u -r1.4 -r1.5 src/sys/rump/kern/lib/libcrypto/Makefile
cvs rdiff -u -r1.175 -r1.176 src/sys/rump/librump/rumpkern/Makefile.rumpkern
cvs rdiff -u -r1.14 -r1.15 src/sys/sys/cprng.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/conf/files
diff -u src/sys/conf/files:1.1237 src/sys/conf/files:1.1238
--- src/sys/conf/files:1.1237	Sat Jun 15 06:40:34 2019
+++ src/sys/conf/files	Mon Sep  2 20:09:29 2019
@@ -1,4 +1,4 @@
-#	$NetBSD: files,v 1.1237 2019/06/15 06:40:34 maxv Exp $
+#	$NetBSD: files,v 1.1238 2019/09/02 20:09:29 riastradh Exp $
 #	@(#)files.newconf	7.5 (Berkeley) 5/10/93
 
 version 	20171118
@@ -196,8 +196,8 @@ include "crypto/camellia/files.camellia"
 # General-purpose crypto processing framework.
 include "opencrypto/files.opencrypto"
 
-# NIST SP800.90 CTR DRBG
-include "crypto/nist_ctr_drbg/files.nist_ctr_drbg"
+# NIST SP800-90A Hash_DRBG
+include "crypto/nist_hash_drbg/files.nist_hash_drbg"
 
 # ChaCha-based fast PRNG
 include "crypto/cprng_fast/files.cprng_fast"

Index: src/sys/kern/subr_cprng.c
diff -u src/sys/kern/subr_cprng.c:1.30 src/sys/kern/subr_cprng.c:1.31
--- src/sys/kern/subr_cprng.c:1.30	Wed Jul 10 17:32:37 2019
+++ src/sys/kern/subr_cprng.c	Mon Sep  2 20:09:30 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: subr_cprng.c,v 1.30 

CVS commit: src/sys

2019-09-02 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Mon Sep  2 20:09:30 UTC 2019

Modified Files:
src/sys/conf: files
src/sys/dev: rndpseudo.c
src/sys/kern: subr_cprng.c
src/sys/rump/kern/lib/libcrypto: Makefile
src/sys/rump/librump/rumpkern: Makefile.rumpkern
src/sys/sys: cprng.h
Added Files:
src/sys/crypto/nist_hash_drbg: files.nist_hash_drbg nist_hash_drbg.c
nist_hash_drbg.h
Removed Files:
src/sys/crypto/nist_ctr_drbg: files.nist_ctr_drbg
nist_ctr_aes_rijndael.h nist_ctr_drbg.c nist_ctr_drbg.h
nist_ctr_drbg_aes128.h nist_ctr_drbg_aes256.h
nist_ctr_drbg_config.h

Log Message:
Switch from NIST CTR_DRBG with AES to NIST Hash_DRBG with SHA-256.

Benefits:

- larger seeds -- a 128-bit key alone is not enough for `128-bit security'
- better resistance to timing side channels than AES
- a better-understood security story (https://eprint.iacr.org/2018/349)
- no loss in compliance with US government standards that nobody ever
  got fired for choosing, at least in the US-dominated western world
- no dirty endianness tricks
- self-tests

Drawbacks:

- performance hit: throughput is reduced to about 1/3 in naive measurements
  => possible to mitigate by using hardware SHA-256 instructions
  => all you really need is 32 bytes to seed a userland PRNG anyway
  => if we just used ChaCha this would go away...

XXX pullup-7
XXX pullup-8
XXX pullup-9


To generate a diff of this commit:
cvs rdiff -u -r1.1237 -r1.1238 src/sys/conf/files
cvs rdiff -u -r1.1 -r0 src/sys/crypto/nist_ctr_drbg/files.nist_ctr_drbg \
src/sys/crypto/nist_ctr_drbg/nist_ctr_drbg.c \
src/sys/crypto/nist_ctr_drbg/nist_ctr_drbg_config.h
cvs rdiff -u -r1.2 -r0 src/sys/crypto/nist_ctr_drbg/nist_ctr_aes_rijndael.h \
src/sys/crypto/nist_ctr_drbg/nist_ctr_drbg_aes128.h \
src/sys/crypto/nist_ctr_drbg/nist_ctr_drbg_aes256.h
cvs rdiff -u -r1.3 -r0 src/sys/crypto/nist_ctr_drbg/nist_ctr_drbg.h
cvs rdiff -u -r0 -r1.1 src/sys/crypto/nist_hash_drbg/files.nist_hash_drbg \
src/sys/crypto/nist_hash_drbg/nist_hash_drbg.c \
src/sys/crypto/nist_hash_drbg/nist_hash_drbg.h
cvs rdiff -u -r1.37 -r1.38 src/sys/dev/rndpseudo.c
cvs rdiff -u -r1.30 -r1.31 src/sys/kern/subr_cprng.c
cvs rdiff -u -r1.4 -r1.5 src/sys/rump/kern/lib/libcrypto/Makefile
cvs rdiff -u -r1.175 -r1.176 src/sys/rump/librump/rumpkern/Makefile.rumpkern
cvs rdiff -u -r1.14 -r1.15 src/sys/sys/cprng.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.
Index: src/sys/dev/rndpseudo.c
diff -u src/sys/dev/rndpseudo.c:1.37 src/sys/dev/rndpseudo.c:1.38
--- src/sys/dev/rndpseudo.c:1.37	Mon Sep  3 16:29:30 2018
+++ src/sys/dev/rndpseudo.c	Mon Sep  2 20:09:30 2019
@@ -1,4 +1,4 @@
-/*	$NetBSD: rndpseudo.c,v 1.37 2018/09/03 16:29:30 riastradh Exp $	*/
+/*	$NetBSD: rndpseudo.c,v 1.38 2019/09/02 20:09:30 riastradh Exp $	*/
 
 /*-
  * Copyright (c) 1997-2013 The NetBSD Foundation, Inc.
@@ -31,7 +31,7 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: rndpseudo.c,v 1.37 2018/09/03 16:29:30 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: rndpseudo.c,v 1.38 2019/09/02 20:09:30 riastradh Exp $");
 
 #if defined(_KERNEL_OPT)
 #include "opt_compat_netbsd.h"
@@ -360,11 +360,12 @@ rnd_read(struct file *fp, off_t *offp, s
 	 * Choose a CPRNG to use -- either the per-open CPRNG, if this
 	 * is /dev/random or a long read, or the per-CPU one otherwise.
 	 *
 	 * XXX NIST_BLOCK_KEYLEN_BYTES is a detail of the cprng(9)
 	 * implementation and as such should not be mentioned here.
 	 */
 	struct cprng_strong *const cprng =
-	((ctx->rc_hard || (uio->uio_resid > NIST_BLOCK_KEYLEN_BYTES))?
+	((ctx->rc_hard ||
+		(uio->uio_resid > NIST_HASH_DRBG_MIN_SEEDLEN_BYTES))?
 		rnd_ctx_cprng(ctx) : rnd_percpu_cprng());
 
 	/*
@@ -360,11 +360,12 @@ rnd_read(struct file *fp, off_t *offp, s
 	 * is /dev/random or a long read, or the per-CPU one otherwise.
 	 *
-	 * XXX NIST_BLOCK_KEYLEN_BYTES is a detail of the cprng(9)
+	 * XXX NIST_HASH_DRBG_MIN_SEEDLEN_BYTES is a detail of the cprng(9)
 	 * implementation and as such should not be mentioned here.
 	 */
